Diff
Modified: trunk/Source/WebKit/ChangeLog (243344 => 243345)
--- trunk/Source/WebKit/ChangeLog 2019-03-21 23:34:31 UTC (rev 243344)
+++ trunk/Source/WebKit/ChangeLog 2019-03-21 23:35:39 UTC (rev 243345)
@@ -1,3 +1,68 @@
+2019-03-21 Alex Christensen <[email protected]>
+
+ Remove last use of LegacySync IPC messages
+ https://bugs.webkit.org/show_bug.cgi?id=196113
+
+ Reviewed by Chris Dumez.
+
+ Also rename "Delayed" to "Synchronous" now that there's only one type of synchronous message.
+
+ * NetworkProcess/NetworkConnectionToWebProcess.messages.in:
+ * NetworkProcess/NetworkProcess.messages.in:
+ * NetworkProcess/ServiceWorker/WebSWServerConnection.cpp:
+ (WebKit::WebSWServerConnection::syncTerminateWorkerFromClient):
+ * NetworkProcess/ServiceWorker/WebSWServerConnection.h:
+ * NetworkProcess/ServiceWorker/WebSWServerConnection.messages.in:
+ * Platform/IPC/Connection.cpp:
+ (IPC::Connection::dispatchMessage):
+ * Platform/IPC/HandleMessage.h:
+ (IPC::handleMessageSynchronous):
+ (IPC::handleMessageSynchronousWantsConnection):
+ (IPC::handleMessageLegacySync): Deleted.
+ (IPC::handleMessageDelayed): Deleted.
+ (IPC::handleMessageDelayedWantsConnection): Deleted.
+ * PluginProcess/PluginControllerProxy.messages.in:
+ * PluginProcess/WebProcessConnection.messages.in:
+ * Scripts/webkit/LegacyMessageReceiver-expected.cpp:
+ (WebKit::WebPage::didReceiveSyncWebPageMessage):
+ * Scripts/webkit/MessageReceiver-expected.cpp:
+ (WebKit::WebPage::didReceiveSyncMessage):
+ * Scripts/webkit/MessageReceiverSuperclass-expected.cpp:
+ (Messages::WebPage::TestSyncMessage::send):
+ (Messages::WebPage::TestSynchronousMessage::send):
+ (WebKit::WebPage::didReceiveSyncMessage):
+ (Messages::WebPage::TestDelayedMessage::send): Deleted.
+ * Scripts/webkit/MessagesSuperclass-expected.h:
+ (Messages::WebPage::TestSynchronousMessage::name):
+ (Messages::WebPage::TestSynchronousMessage::TestSynchronousMessage):
+ (Messages::WebPage::TestDelayedMessage::receiverName): Deleted.
+ (Messages::WebPage::TestDelayedMessage::name): Deleted.
+ (Messages::WebPage::TestDelayedMessage::TestDelayedMessage): Deleted.
+ (Messages::WebPage::TestDelayedMessage::arguments const): Deleted.
+ * Scripts/webkit/messages.py:
+ * Scripts/webkit/messages_unittest.py:
+ * Scripts/webkit/test-legacy-messages.in:
+ * Scripts/webkit/test-messages.in:
+ * Scripts/webkit/test-superclass-messages.in:
+ * Shared/ApplePay/WebPaymentCoordinatorProxy.messages.in:
+ * Shared/Plugins/NPObjectMessageReceiver.messages.in:
+ * UIProcess/Cocoa/UserMediaCaptureManagerProxy.messages.in:
+ * UIProcess/Plugins/PluginProcessProxy.messages.in:
+ * UIProcess/WebFullScreenManagerProxy.messages.in:
+ * UIProcess/WebPageProxy.messages.in:
+ * UIProcess/WebPasteboardProxy.messages.in:
+ * UIProcess/WebProcessPool.messages.in:
+ * UIProcess/WebProcessProxy.messages.in:
+ * UIProcess/WebStorage/StorageManager.messages.in:
+ * UIProcess/mac/SecItemShimProxy.messages.in:
+ * WebProcess/Plugins/PluginProcessConnection.messages.in:
+ * WebProcess/Plugins/PluginProxy.messages.in:
+ * WebProcess/Storage/WebSWClientConnection.cpp:
+ (WebKit::WebSWClientConnection::syncTerminateWorker):
+ * WebProcess/Storage/WebSWContextManagerConnection.messages.in:
+ * WebProcess/WebPage/WebPage.messages.in:
+ * WebProcess/WebProcess.messages.in:
+
2019-03-21 Brian Burg <[email protected]>
Web Automation: support uploading non-local file paths
Modified: trunk/Source/WebKit/NetworkProcess/NetworkConnectionToWebProcess.messages.in (243344 => 243345)
--- trunk/Source/WebKit/NetworkProcess/NetworkConnectionToWebProcess.messages.in 2019-03-21 23:34:31 UTC (rev 243344)
+++ trunk/Source/WebKit/NetworkProcess/NetworkConnectionToWebProcess.messages.in 2019-03-21 23:35:39 UTC (rev 243345)
@@ -23,7 +23,7 @@
messages -> NetworkConnectionToWebProcess LegacyReceiver {
ScheduleResourceLoad(WebKit::NetworkResourceLoadParameters resourceLoadParameters)
- PerformSynchronousLoad(WebKit::NetworkResourceLoadParameters resourceLoadParameters) -> (WebCore::ResourceError error, WebCore::ResourceResponse response, Vector<char> data) Delayed
+ PerformSynchronousLoad(WebKit::NetworkResourceLoadParameters resourceLoadParameters) -> (WebCore::ResourceError error, WebCore::ResourceResponse response, Vector<char> data) Synchronous
LoadPing(WebKit::NetworkResourceLoadParameters resourceLoadParameters)
RemoveLoadIdentifier(uint64_t resourceLoadIdentifier)
PageLoadCompleted(uint64_t webPageID)
@@ -33,11 +33,11 @@
StartDownload(PAL::SessionID sessionID, WebKit::DownloadID downloadID, WebCore::ResourceRequest request, String suggestedName)
ConvertMainResourceLoadToDownload(PAL::SessionID sessionID, uint64_t mainResourceLoadIdentifier, WebKit::DownloadID downloadID, WebCore::ResourceRequest request, WebCore::ResourceResponse response)
- CookiesForDOM(PAL::SessionID sessionID, URL firstParty, struct WebCore::SameSiteInfo sameSiteInfo, URL url, Optional<uint64_t> frameID, Optional<uint64_t> pageID, enum:bool WebCore::IncludeSecureCookies includeSecureCookies) -> (String cookieString, bool didAccessSecureCookies) Delayed
+ CookiesForDOM(PAL::SessionID sessionID, URL firstParty, struct WebCore::SameSiteInfo sameSiteInfo, URL url, Optional<uint64_t> frameID, Optional<uint64_t> pageID, enum:bool WebCore::IncludeSecureCookies includeSecureCookies) -> (String cookieString, bool didAccessSecureCookies) Synchronous
SetCookiesFromDOM(PAL::SessionID sessionID, URL firstParty, struct WebCore::SameSiteInfo sameSiteInfo, URL url, Optional<uint64_t> frameID, Optional<uint64_t> pageID, String cookieString)
- CookiesEnabled(PAL::SessionID sessionID) -> (bool enabled) Delayed
- CookieRequestHeaderFieldValue(PAL::SessionID sessionID, URL firstParty, struct WebCore::SameSiteInfo sameSiteInfo, URL url, Optional<uint64_t> frameID, Optional<uint64_t> pageID, enum:bool WebCore::IncludeSecureCookies includeSecureCookies) -> (String cookieString, bool didAccessSecureCookies) Delayed
- GetRawCookies(PAL::SessionID sessionID, URL firstParty, struct WebCore::SameSiteInfo sameSiteInfo, URL url, Optional<uint64_t> frameID, Optional<uint64_t> pageID) -> (Vector<WebCore::Cookie> cookies) Delayed
+ CookiesEnabled(PAL::SessionID sessionID) -> (bool enabled) Synchronous
+ CookieRequestHeaderFieldValue(PAL::SessionID sessionID, URL firstParty, struct WebCore::SameSiteInfo sameSiteInfo, URL url, Optional<uint64_t> frameID, Optional<uint64_t> pageID, enum:bool WebCore::IncludeSecureCookies includeSecureCookies) -> (String cookieString, bool didAccessSecureCookies) Synchronous
+ GetRawCookies(PAL::SessionID sessionID, URL firstParty, struct WebCore::SameSiteInfo sameSiteInfo, URL url, Optional<uint64_t> frameID, Optional<uint64_t> pageID) -> (Vector<WebCore::Cookie> cookies) Synchronous
DeleteCookie(PAL::SessionID sessionID, URL url, String cookieName)
RegisterFileBlobURL(URL url, String path, WebKit::SandboxExtension::Handle extensionHandle, String contentType)
@@ -46,7 +46,7 @@
RegisterBlobURLOptionallyFileBacked(URL url, URL srcURL, String fileBackedPath, String contentType)
RegisterBlobURLForSlice(URL url, URL srcURL, int64_t start, int64_t end)
UnregisterBlobURL(URL url)
- BlobSize(URL url) -> (uint64_t resultSize) Delayed
+ BlobSize(URL url) -> (uint64_t resultSize) Synchronous
WriteBlobsToTemporaryFiles(Vector<String> blobURLs) -> (Vector<String> fileNames) Async
SetCaptureExtraNetworkLoadMetricsEnabled(bool enabled)
@@ -71,17 +71,17 @@
RemoveOriginAccessWhitelistEntry(String sourceOrigin, String destinationProtocol, String destinationHost, bool allowDestinationSubdomains);
ResetOriginAccessWhitelists();
- GetNetworkLoadInformationRequest(uint64_t resourceLoadIdentifier) -> (WebCore::ResourceRequest request) Delayed
- GetNetworkLoadInformationResponse(uint64_t resourceLoadIdentifier) -> (WebCore::ResourceResponse response) Delayed
- GetNetworkLoadIntermediateInformation(uint64_t resourceLoadIdentifier) -> (Vector<WebCore::NetworkTransactionInformation> transactions) Delayed
- TakeNetworkLoadInformationMetrics(uint64_t resourceLoadIdentifier) -> (WebCore::NetworkLoadMetrics networkMetrics) Delayed
+ GetNetworkLoadInformationRequest(uint64_t resourceLoadIdentifier) -> (WebCore::ResourceRequest request) Synchronous
+ GetNetworkLoadInformationResponse(uint64_t resourceLoadIdentifier) -> (WebCore::ResourceResponse response) Synchronous
+ GetNetworkLoadIntermediateInformation(uint64_t resourceLoadIdentifier) -> (Vector<WebCore::NetworkTransactionInformation> transactions) Synchronous
+ TakeNetworkLoadInformationMetrics(uint64_t resourceLoadIdentifier) -> (WebCore::NetworkLoadMetrics networkMetrics) Synchronous
#if ENABLE(INDEXED_DATABASE)
- EstablishIDBConnectionToServer(PAL::SessionID sessionID) -> (uint64_t serverConnectionIdentifier) Delayed
+ EstablishIDBConnectionToServer(PAL::SessionID sessionID) -> (uint64_t serverConnectionIdentifier) Synchronous
#endif
#if ENABLE(SERVICE_WORKER)
- EstablishSWServerConnection(PAL::SessionID sessionID) -> (WebCore::SWServerConnectionIdentifier serverConnectionIdentifier) Delayed
+ EstablishSWServerConnection(PAL::SessionID sessionID) -> (WebCore::SWServerConnectionIdentifier serverConnectionIdentifier) Synchronous
#endif
SetWebProcessIdentifier(WebCore::ProcessIdentifier processIdentifier)
Modified: trunk/Source/WebKit/NetworkProcess/NetworkProcess.messages.in (243344 => 243345)
--- trunk/Source/WebKit/NetworkProcess/NetworkProcess.messages.in 2019-03-21 23:34:31 UTC (rev 243344)
+++ trunk/Source/WebKit/NetworkProcess/NetworkProcess.messages.in 2019-03-21 23:35:39 UTC (rev 243345)
@@ -62,7 +62,7 @@
SetQOS(int latencyQOS, int throughputQOS)
SetStorageAccessAPIEnabled(bool enabled)
#endif
- SetAllowsAnySSLCertificateForWebSocket(bool enabled) -> () Delayed
+ SetAllowsAnySSLCertificateForWebSocket(bool enabled) -> () Synchronous
SyncAllCookies()
@@ -77,7 +77,7 @@
ProcessDidTransitionToBackground()
ProcessDidTransitionToForeground()
- ProcessWillSuspendImminently() -> (bool handled) Delayed
+ ProcessWillSuspendImminently() -> (bool handled) Synchronous
PrepareToSuspend()
CancelPrepareToSuspend()
ProcessDidResume()
Modified: trunk/Source/WebKit/NetworkProcess/ServiceWorker/WebSWServerConnection.cpp (243344 => 243345)
--- trunk/Source/WebKit/NetworkProcess/ServiceWorker/WebSWServerConnection.cpp 2019-03-21 23:34:31 UTC (rev 243344)
+++ trunk/Source/WebKit/NetworkProcess/ServiceWorker/WebSWServerConnection.cpp 2019-03-21 23:35:39 UTC (rev 243345)
@@ -290,6 +290,12 @@
m_clientOrigins.remove(iterator);
}
+void WebSWServerConnection::syncTerminateWorkerFromClient(WebCore::ServiceWorkerIdentifier&& identifier, CompletionHandler<void()>&& completionHandler)
+{
+ syncTerminateWorker(WTFMove(identifier));
+ completionHandler();
+}
+
template<typename U> void WebSWServerConnection::sendToContextProcess(WebCore::SWServerToContextConnection& connection, U&& message)
{
static_cast<WebSWServerToContextConnection&>(connection).send(WTFMove(message));
Modified: trunk/Source/WebKit/NetworkProcess/ServiceWorker/WebSWServerConnection.h (243344 => 243345)
--- trunk/Source/WebKit/NetworkProcess/ServiceWorker/WebSWServerConnection.h 2019-03-21 23:34:31 UTC (rev 243344)
+++ trunk/Source/WebKit/NetworkProcess/ServiceWorker/WebSWServerConnection.h 2019-03-21 23:35:39 UTC (rev 243345)
@@ -92,6 +92,7 @@
void registerServiceWorkerClient(WebCore::SecurityOriginData&& topOrigin, WebCore::ServiceWorkerClientData&&, const Optional<WebCore::ServiceWorkerRegistrationIdentifier>&, String&& userAgent);
void unregisterServiceWorkerClient(const WebCore::ServiceWorkerClientIdentifier&);
+ void syncTerminateWorkerFromClient(WebCore::ServiceWorkerIdentifier&&, CompletionHandler<void()>&&);
IPC::Connection* messageSenderConnection() const final { return m_contentConnection.ptr(); }
uint64_t messageSenderDestinationID() const final { return identifier().toUInt64(); }
Modified: trunk/Source/WebKit/NetworkProcess/ServiceWorker/WebSWServerConnection.messages.in (243344 => 243345)
--- trunk/Source/WebKit/NetworkProcess/ServiceWorker/WebSWServerConnection.messages.in 2019-03-21 23:34:31 UTC (rev 243344)
+++ trunk/Source/WebKit/NetworkProcess/ServiceWorker/WebSWServerConnection.messages.in 2019-03-21 23:35:39 UTC (rev 243345)
@@ -43,7 +43,7 @@
RegisterServiceWorkerClient(struct WebCore::SecurityOriginData topOrigin, struct WebCore::ServiceWorkerClientData data, Optional<WebCore::ServiceWorkerRegistrationIdentifier> controllingServiceWorkerRegistrationIdentifier, String userAgent)
UnregisterServiceWorkerClient(struct WebCore::ServiceWorkerClientIdentifier identifier)
- SyncTerminateWorker(WebCore::ServiceWorkerIdentifier workerIdentifier) -> () LegacySync
+ SyncTerminateWorkerFromClient(WebCore::ServiceWorkerIdentifier workerIdentifier) -> () Synchronous
}
#endif // ENABLE(SERVICE_WORKER)
Modified: trunk/Source/WebKit/Platform/IPC/Connection.cpp (243344 => 243345)
--- trunk/Source/WebKit/Platform/IPC/Connection.cpp 2019-03-21 23:34:31 UTC (rev 243344)
+++ trunk/Source/WebKit/Platform/IPC/Connection.cpp 2019-03-21 23:35:39 UTC (rev 243345)
@@ -1012,7 +1012,7 @@
m_didReceiveInvalidMessage |= message->isInvalid();
m_inDispatchMessageCount--;
- // FIXME: For Delayed synchronous messages, we should not decrement the counter until we send a response.
+ // FIXME: For synchronous messages, we should not decrement the counter until we send a response.
// Otherwise, we would deadlock if processing the message results in a sync message back after we exit this function.
if (message->shouldDispatchMessageWhenWaitingForSyncReply())
m_inDispatchMessageMarkedDispatchWhenWaitingForSyncReplyCount--;
Modified: trunk/Source/WebKit/Platform/IPC/HandleMessage.h (243344 => 243345)
--- trunk/Source/WebKit/PluginProcess/PluginControllerProxy.messages.in 2019-03-21 23:34:31 UTC (rev 243344)
+++ trunk/Source/WebKit/PluginProcess/PluginControllerProxy.messages.in 2019-03-21 23:35:39 UTC (rev 243345)
@@ -69,28 +69,28 @@
HandleMouseEvent(WebKit::WebMouseEvent mouseEvent)
# Sent when a mouse wheel event should be processed.
- HandleWheelEvent(WebKit::WebWheelEvent wheelEvent) -> (bool handled) Delayed
+ HandleWheelEvent(WebKit::WebWheelEvent wheelEvent) -> (bool handled) Synchronous
# Sent when a mouse enter event should be processed.
- HandleMouseEnterEvent(WebKit::WebMouseEvent mouseEvent) -> (bool handled) Delayed
+ HandleMouseEnterEvent(WebKit::WebMouseEvent mouseEvent) -> (bool handled) Synchronous
# Sent when a mouse leave event should be processed.
- HandleMouseLeaveEvent(WebKit::WebMouseEvent mouseEvent) -> (bool handled) Delayed
+ HandleMouseLeaveEvent(WebKit::WebMouseEvent mouseEvent) -> (bool handled) Synchronous
# Sent when a keyboard should be processed.
- HandleKeyboardEvent(WebKit::WebKeyboardEvent keyboardEvent) -> (bool handled) Delayed
+ HandleKeyboardEvent(WebKit::WebKeyboardEvent keyboardEvent) -> (bool handled) Synchronous
# Sent when an editing command should be processed.
- HandleEditingCommand(String commandName, String argument) -> (bool handled) Delayed
+ HandleEditingCommand(String commandName, String argument) -> (bool handled) Synchronous
# Return whether or not a plugin wants to enable the given editing command.
- IsEditingCommandEnabled(String commandName) -> (bool enabled) Delayed
+ IsEditingCommandEnabled(String commandName) -> (bool enabled) Synchronous
# Return whether or not a plugin wants to handle page scale factor itself.
- HandlesPageScaleFactor() -> (bool enabled) Delayed
+ HandlesPageScaleFactor() -> (bool enabled) Synchronous
# Return whether or not a plugin wants page scale, page zoom, and text zoom all to affect page scale.
- RequiresUnifiedScaleFactor() -> (bool required) Delayed
+ RequiresUnifiedScaleFactor() -> (bool required) Synchronous
# Sent when the plug-in focus changes.
SetFocus(bool isFocused)
@@ -99,10 +99,10 @@
DidUpdate()
# Paint the entire plug-in.
- PaintEntirePlugin() -> () Delayed
+ PaintEntirePlugin() -> () Synchronous
# Get a reference to the plug-in's scriptable NPObject.
- GetPluginScriptableNPObject() -> (uint64_t pluginScriptableNPObjectID) Delayed
+ GetPluginScriptableNPObject() -> (uint64_t pluginScriptableNPObjectID) Synchronous
# Sent when the containing NSWindow's focus changes
WindowFocusChanged(bool hasFocus)
@@ -122,10 +122,10 @@
#endif
# Does the plugin support snapshotting?
- SupportsSnapshotting() -> (bool isSupported) Delayed
+ SupportsSnapshotting() -> (bool isSupported) Synchronous
# Return a snapshot of the plugin.
- Snapshot() -> (WebKit::ShareableBitmap::Handle backingStoreHandle) Delayed
+ Snapshot() -> (WebKit::ShareableBitmap::Handle backingStoreHandle) Synchronous
# Sent when storage blocking policy changes
StorageBlockingStateChanged(bool storageBlockingEnabled)
@@ -134,7 +134,7 @@
PrivateBrowsingStateChanged(bool isPrivateBrowsingEnabled)
# Gets the string representating the form value of the plug-in
- GetFormValue() -> (bool returnValue, String formValue) Delayed
+ GetFormValue() -> (bool returnValue, String formValue) Synchronous
# Sent when the browser wants to mute or unmute the plugin.
MutedStateChanged(bool muted)
Modified: trunk/Source/WebKit/PluginProcess/WebProcessConnection.messages.in (243344 => 243345)
--- trunk/Source/WebKit/PluginProcess/WebProcessConnection.messages.in 2019-03-21 23:34:31 UTC (rev 243344)
+++ trunk/Source/WebKit/PluginProcess/WebProcessConnection.messages.in 2019-03-21 23:35:39 UTC (rev 243345)
@@ -24,13 +24,13 @@
messages -> WebProcessConnection LegacyReceiver {
# Creates a plug-in instance using the given creation parameters.
- CreatePlugin(struct WebKit::PluginCreationParameters pluginCreationParameters) -> (bool creationResult, bool wantsWheelEvents, uint32_t remoteLayerClientID) Delayed
+ CreatePlugin(struct WebKit::PluginCreationParameters pluginCreationParameters) -> (bool creationResult, bool wantsWheelEvents, uint32_t remoteLayerClientID) Synchronous
# Creates a plug-in instance asynchronously using the given creation parameters.
CreatePluginAsynchronously(struct WebKit::PluginCreationParameters pluginCreationParameters)
# Destroys the plug-in instance with the given instance ID.
- DestroyPlugin(uint64_t pluginInstanceID, bool asynchronousCreationIncomplete) -> () Delayed
+ DestroyPlugin(uint64_t pluginInstanceID, bool asynchronousCreationIncomplete) -> () Synchronous
}
#endif
Modified: trunk/Source/WebKit/Scripts/webkit/LegacyMessageReceiver-expected.cpp (243344 => 243345)
--- trunk/Source/WebKit/Scripts/webkit/LegacyMessageReceiver-expected.cpp 2019-03-21 23:34:31 UTC (rev 243344)
+++ trunk/Source/WebKit/Scripts/webkit/LegacyMessageReceiver-expected.cpp 2019-03-21 23:35:39 UTC (rev 243345)
@@ -176,11 +176,11 @@
return;
}
if (decoder.messageName() == Messages::WebPage::GetPluginProcessConnection::name()) {
- IPC::handleMessageDelayed<Messages::WebPage::GetPluginProcessConnection>(connection, decoder, replyEncoder, this, &WebPage::getPluginProcessConnection);
+ IPC::handleMessageSynchronous<Messages::WebPage::GetPluginProcessConnection>(connection, decoder, replyEncoder, this, &WebPage::getPluginProcessConnection);
return;
}
if (decoder.messageName() == Messages::WebPage::TestMultipleAttributes::name()) {
- IPC::handleMessageDelayedWantsConnection<Messages::WebPage::TestMultipleAttributes>(connection, decoder, replyEncoder, this, &WebPage::testMultipleAttributes);
+ IPC::handleMessageSynchronousWantsConnection<Messages::WebPage::TestMultipleAttributes>(connection, decoder, replyEncoder, this, &WebPage::testMultipleAttributes);
return;
}
#if PLATFORM(MAC)
Modified: trunk/Source/WebKit/Scripts/webkit/MessageReceiver-expected.cpp (243344 => 243345)
--- trunk/Source/WebKit/Scripts/webkit/MessageReceiver-expected.cpp 2019-03-21 23:34:31 UTC (rev 243344)
+++ trunk/Source/WebKit/Scripts/webkit/MessageReceiver-expected.cpp 2019-03-21 23:35:39 UTC (rev 243345)
@@ -176,11 +176,11 @@
return;
}
if (decoder.messageName() == Messages::WebPage::GetPluginProcessConnection::name()) {
- IPC::handleMessageDelayed<Messages::WebPage::GetPluginProcessConnection>(connection, decoder, replyEncoder, this, &WebPage::getPluginProcessConnection);
+ IPC::handleMessageSynchronous<Messages::WebPage::GetPluginProcessConnection>(connection, decoder, replyEncoder, this, &WebPage::getPluginProcessConnection);
return;
}
if (decoder.messageName() == Messages::WebPage::TestMultipleAttributes::name()) {
- IPC::handleMessageDelayedWantsConnection<Messages::WebPage::TestMultipleAttributes>(connection, decoder, replyEncoder, this, &WebPage::testMultipleAttributes);
+ IPC::handleMessageSynchronousWantsConnection<Messages::WebPage::TestMultipleAttributes>(connection, decoder, replyEncoder, this, &WebPage::testMultipleAttributes);
return;
}
#if PLATFORM(MAC)
Modified: trunk/Source/WebKit/Scripts/webkit/MessageReceiverSuperclass-expected.cpp (243344 => 243345)
--- trunk/Source/WebKit/Scripts/webkit/MessageReceiverSuperclass-expected.cpp 2019-03-21 23:34:31 UTC (rev 243344)
+++ trunk/Source/WebKit/Scripts/webkit/MessageReceiverSuperclass-expected.cpp 2019-03-21 23:35:39 UTC (rev 243345)
@@ -119,8 +119,14 @@
#endif
-void TestDelayedMessage::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection, const Optional<WebKit::TestClassName>& optionalReply)
+void TestSyncMessage::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection, uint8_t reply)
{
+ *encoder << reply;
+ connection.sendSyncReply(WTFMove(encoder));
+}
+
+void TestSynchronousMessage::send(std::unique_ptr<IPC::Encoder>&& encoder, IPC::Connection& connection, const Optional<WebKit::TestClassName>& optionalReply)
+{
*encoder << optionalReply;
connection.sendSyncReply(WTFMove(encoder));
}
@@ -161,11 +167,11 @@
void WebPage::didReceiveSyncMessage(IPC::Connection& connection, IPC::Decoder& decoder, std::unique_ptr<IPC::Encoder>& replyEncoder)
{
if (decoder.messageName() == Messages::WebPage::TestSyncMessage::name()) {
- IPC::handleMessage<Messages::WebPage::TestSyncMessage>(decoder, *replyEncoder, this, &WebPage::testSyncMessage);
+ IPC::handleMessageSynchronous<Messages::WebPage::TestSyncMessage>(connection, decoder, replyEncoder, this, &WebPage::testSyncMessage);
return;
}
- if (decoder.messageName() == Messages::WebPage::TestDelayedMessage::name()) {
- IPC::handleMessageDelayed<Messages::WebPage::TestDelayedMessage>(connection, decoder, replyEncoder, this, &WebPage::testDelayedMessage);
+ if (decoder.messageName() == Messages::WebPage::TestSynchronousMessage::name()) {
+ IPC::handleMessageSynchronous<Messages::WebPage::TestSynchronousMessage>(connection, decoder, replyEncoder, this, &WebPage::testSynchronousMessage);
return;
}
UNUSED_PARAM(connection);
Modified: trunk/Source/WebKit/Scripts/webkit/MessagesSuperclass-expected.h (243344 => 243345)
--- trunk/Source/WebKit/Scripts/webkit/MessagesSuperclass-expected.h 2019-03-21 23:34:31 UTC (rev 243344)
+++ trunk/Source/WebKit/Scripts/webkit/MessagesSuperclass-expected.h 2019-03-21 23:35:39 UTC (rev 243345)
@@ -154,6 +154,8 @@
static IPC::StringReference name() { return IPC::StringReference("TestSyncMessage"); }
static const bool isSync = true;
+ using DelayedReply = CompletionHandler<void(uint8_t reply)>;
+ static void send(std::unique_ptr<IPC::Encoder>&&, IPC::Connection&, uint8_t reply);
typedef std::tuple<uint8_t&> Reply;
explicit TestSyncMessage(uint32_t param)
: m_arguments(param)
@@ -169,18 +171,18 @@
Arguments m_arguments;
};
-class TestDelayedMessage {
+class TestSynchronousMessage {
public:
typedef std::tuple<bool> Arguments;
static IPC::StringReference receiverName() { return messageReceiverName(); }
- static IPC::StringReference name() { return IPC::StringReference("TestDelayedMessage"); }
+ static IPC::StringReference name() { return IPC::StringReference("TestSynchronousMessage"); }
static const bool isSync = true;
using DelayedReply = CompletionHandler<void(const Optional<WebKit::TestClassName>& optionalReply)>;
static void send(std::unique_ptr<IPC::Encoder>&&, IPC::Connection&, const Optional<WebKit::TestClassName>& optionalReply);
typedef std::tuple<Optional<WebKit::TestClassName>&> Reply;
- explicit TestDelayedMessage(bool value)
+ explicit TestSynchronousMessage(bool value)
: m_arguments(value)
{
}
Modified: trunk/Source/WebKit/Scripts/webkit/messages.py (243344 => 243345)
--- trunk/Source/WebKit/Scripts/webkit/messages.py 2019-03-21 23:34:31 UTC (rev 243344)
+++ trunk/Source/WebKit/Scripts/webkit/messages.py 2019-03-21 23:35:39 UTC (rev 243345)
@@ -28,9 +28,8 @@
WANTS_CONNECTION_ATTRIBUTE = 'WantsConnection'
LEGACY_RECEIVER_ATTRIBUTE = 'LegacyReceiver'
-DELAYED_ATTRIBUTE = 'Delayed'
+SYNCHRONOUS_ATTRIBUTE = 'Synchronous'
ASYNC_ATTRIBUTE = 'Async'
-LEGACY_SYNC_ATTRIBUTE = 'LegacySync'
_license_header = """/*
* Copyright (C) 2010-2018 Apple Inc. All rights reserved.
@@ -130,9 +129,9 @@
result.append(' static void cancelReply(CompletionHandler<void(%s)>&&);\n' % move_parameters)
result.append(' static IPC::StringReference asyncMessageReplyName() { return { "%sReply" }; }\n' % message.name)
result.append(' using AsyncReply')
- elif message.has_attribute(DELAYED_ATTRIBUTE):
+ elif message.has_attribute(SYNCHRONOUS_ATTRIBUTE):
result.append(' using DelayedReply')
- if message.has_attribute(DELAYED_ATTRIBUTE) or message.has_attribute(ASYNC_ATTRIBUTE):
+ if message.has_attribute(SYNCHRONOUS_ATTRIBUTE) or message.has_attribute(ASYNC_ATTRIBUTE):
result.append(' = CompletionHandler<void(%s)>;\n' % completion_handler_parameters)
result.append(' static void send(std::unique_ptr<IPC::Encoder>&&, IPC::Connection&')
if len(send_parameters):
@@ -304,20 +303,18 @@
def sync_message_statement(receiver, message):
dispatch_function = 'handleMessage'
- if message.has_attribute(DELAYED_ATTRIBUTE):
- dispatch_function += 'Delayed'
+ if message.has_attribute(SYNCHRONOUS_ATTRIBUTE):
+ dispatch_function += 'Synchronous'
if message.has_attribute(WANTS_CONNECTION_ATTRIBUTE):
dispatch_function += 'WantsConnection'
if message.has_attribute(ASYNC_ATTRIBUTE):
dispatch_function += 'Async'
- if message.has_attribute(LEGACY_SYNC_ATTRIBUTE):
- dispatch_function += 'LegacySync'
- wants_connection = message.has_attribute(DELAYED_ATTRIBUTE) or message.has_attribute(WANTS_CONNECTION_ATTRIBUTE)
+ wants_connection = message.has_attribute(SYNCHRONOUS_ATTRIBUTE) or message.has_attribute(WANTS_CONNECTION_ATTRIBUTE)
result = []
result.append(' if (decoder.messageName() == Messages::%s::%s::name()) {\n' % (receiver.name, message.name))
- result.append(' IPC::%s<Messages::%s::%s>(%sdecoder, %sreplyEncoder, this, &%s);\n' % (dispatch_function, receiver.name, message.name, 'connection, ' if wants_connection else '', '' if message.has_attribute(DELAYED_ATTRIBUTE) or message.has_attribute(ASYNC_ATTRIBUTE) else '*', handler_function(receiver, message)))
+ result.append(' IPC::%s<Messages::%s::%s>(%sdecoder, %sreplyEncoder, this, &%s);\n' % (dispatch_function, receiver.name, message.name, 'connection, ' if wants_connection else '', '' if message.has_attribute(SYNCHRONOUS_ATTRIBUTE) or message.has_attribute(ASYNC_ATTRIBUTE) else '*', handler_function(receiver, message)))
result.append(' return;\n')
result.append(' }\n')
return surround_in_condition(''.join(result), message.condition)
@@ -555,7 +552,7 @@
delayed_or_async_messages = []
for message in receiver.messages:
- if message.reply_parameters != None and (message.has_attribute(DELAYED_ATTRIBUTE) or message.has_attribute(ASYNC_ATTRIBUTE)):
+ if message.reply_parameters != None and (message.has_attribute(SYNCHRONOUS_ATTRIBUTE) or message.has_attribute(ASYNC_ATTRIBUTE)):
delayed_or_async_messages.append(message)
if delayed_or_async_messages:
Modified: trunk/Source/WebKit/Scripts/webkit/messages_unittest.py (243344 => 243345)
--- trunk/Source/WebKit/Scripts/webkit/messages_unittest.py 2019-03-21 23:34:31 UTC (rev 243344)
+++ trunk/Source/WebKit/Scripts/webkit/messages_unittest.py 2019-03-21 23:35:39 UTC (rev 243345)
@@ -280,7 +280,7 @@
'conditions': (None),
},
{
- 'name': 'TestDelayedMessage',
+ 'name': 'TestSynchronousMessage',
'parameters': (
('bool', 'value'),
),
Modified: trunk/Source/WebKit/Scripts/webkit/test-legacy-messages.in (243344 => 243345)
--- trunk/Source/WebKit/Scripts/webkit/test-legacy-messages.in 2019-03-21 23:34:31 UTC (rev 243344)
+++ trunk/Source/WebKit/Scripts/webkit/test-legacy-messages.in 2019-03-21 23:35:39 UTC (rev 243345)
@@ -45,9 +45,9 @@
CreatePlugin(uint64_t pluginInstanceID, WebKit::Plugin::Parameters parameters) -> (bool result)
RunJavaScriptAlert(uint64_t frameID, String message) -> ()
GetPlugins(bool refresh) -> (Vector<WebCore::PluginInfo> plugins)
- GetPluginProcessConnection(String pluginPath) -> (IPC::Connection::Handle connectionHandle) Delayed
+ GetPluginProcessConnection(String pluginPath) -> (IPC::Connection::Handle connectionHandle) Synchronous
- TestMultipleAttributes() -> () WantsConnection Delayed
+ TestMultipleAttributes() -> () WantsConnection Synchronous
TestParameterAttributes([AttributeOne AttributeTwo] uint64_t foo, double bar, [AttributeThree] double baz)
Modified: trunk/Source/WebKit/Scripts/webkit/test-messages.in (243344 => 243345)
--- trunk/Source/WebKit/Scripts/webkit/test-messages.in 2019-03-21 23:34:31 UTC (rev 243344)
+++ trunk/Source/WebKit/Scripts/webkit/test-messages.in 2019-03-21 23:35:39 UTC (rev 243345)
@@ -52,9 +52,9 @@
CreatePlugin(uint64_t pluginInstanceID, WebKit::Plugin::Parameters parameters) -> (bool result)
RunJavaScriptAlert(uint64_t frameID, String message) -> ()
GetPlugins(bool refresh) -> (Vector<WebCore::PluginInfo> plugins)
- GetPluginProcessConnection(String pluginPath) -> (IPC::Connection::Handle connectionHandle) Delayed
+ GetPluginProcessConnection(String pluginPath) -> (IPC::Connection::Handle connectionHandle) Synchronous
- TestMultipleAttributes() -> () WantsConnection Delayed
+ TestMultipleAttributes() -> () WantsConnection Synchronous
TestParameterAttributes([AttributeOne AttributeTwo] uint64_t foo, double bar, [AttributeThree] double baz)
Modified: trunk/Source/WebKit/Scripts/webkit/test-superclass-messages.in (243344 => 243345)
--- trunk/Source/WebKit/Scripts/webkit/test-superclass-messages.in 2019-03-21 23:34:31 UTC (rev 243344)
+++ trunk/Source/WebKit/Scripts/webkit/test-superclass-messages.in 2019-03-21 23:35:39 UTC (rev 243345)
@@ -27,6 +27,6 @@
TestAsyncMessageWithNoArguments() -> () Async
TestAsyncMessageWithMultipleArguments() -> (bool flag, uint64_t value) Async
#endif
- TestSyncMessage(uint32_t param) -> (uint8_t reply) Sync
- TestDelayedMessage(bool value) -> (Optional<WebKit::TestClassName> optionalReply) Delayed
+ TestSyncMessage(uint32_t param) -> (uint8_t reply) Synchronous
+ TestSynchronousMessage(bool value) -> (Optional<WebKit::TestClassName> optionalReply) Synchronous
}
Modified: trunk/Source/WebKit/Shared/ApplePay/WebPaymentCoordinatorProxy.messages.in (243344 => 243345)
--- trunk/Source/WebKit/Shared/ApplePay/WebPaymentCoordinatorProxy.messages.in 2019-03-21 23:34:31 UTC (rev 243344)
+++ trunk/Source/WebKit/Shared/ApplePay/WebPaymentCoordinatorProxy.messages.in 2019-03-21 23:35:39 UTC (rev 243345)
@@ -26,12 +26,12 @@
messages -> WebPaymentCoordinatorProxy {
- AvailablePaymentNetworks() -> (Vector<String> availablePaymentNetworks) Delayed
- CanMakePayments() -> (bool result) Delayed
+ AvailablePaymentNetworks() -> (Vector<String> availablePaymentNetworks) Synchronous
+ CanMakePayments() -> (bool result) Synchronous
CanMakePaymentsWithActiveCard(String merchantIdentifier, String domainName, PAL::SessionID sessionID) -> (bool canMakePayments) Async
OpenPaymentSetup(String merchantIdentifier, String domainName) -> (bool result) Async
- ShowPaymentUI(uint64_t destinationID, PAL::SessionID sessionID, String originatingURLString, Vector<String> linkIconURLStrings, WebCore::ApplePaySessionPaymentRequest paymentRequest) -> (bool result) Delayed
+ ShowPaymentUI(uint64_t destinationID, PAL::SessionID sessionID, String originatingURLString, Vector<String> linkIconURLStrings, WebCore::ApplePaySessionPaymentRequest paymentRequest) -> (bool result) Synchronous
CompleteMerchantValidation(WebCore::PaymentMerchantSession paymentMerchantSession)
CompleteShippingMethodSelection(Optional<WebCore::ShippingMethodUpdate> update)
CompleteShippingContactSelection(Optional<WebCore::ShippingContactUpdate> update)
Modified: trunk/Source/WebKit/Shared/Plugins/NPObjectMessageReceiver.messages.in (243344 => 243345)
--- trunk/Source/WebKit/Shared/Plugins/NPObjectMessageReceiver.messages.in 2019-03-21 23:34:31 UTC (rev 243344)
+++ trunk/Source/WebKit/Shared/Plugins/NPObjectMessageReceiver.messages.in 2019-03-21 23:35:39 UTC (rev 243345)
@@ -23,16 +23,16 @@
#if ENABLE(NETSCAPE_PLUGIN_API)
messages -> NPObjectMessageReceiver LegacyReceiver {
- Deallocate() -> () Delayed
- HasMethod(WebKit::NPIdentifierData methodName) -> (bool returnValue) Delayed
- Invoke(WebKit::NPIdentifierData methodName, Vector<WebKit::NPVariantData> argumentsData) -> (bool returnValue, WebKit::NPVariantData resultData) Delayed
- InvokeDefault(Vector<WebKit::NPVariantData> argumentsData) -> (bool returnValue, WebKit::NPVariantData resultData) Delayed
- HasProperty(WebKit::NPIdentifierData propertyName) -> (bool returnValue) Delayed
- GetProperty(WebKit::NPIdentifierData propertyName) -> (bool returnValue, WebKit::NPVariantData resultData) Delayed
- SetProperty(WebKit::NPIdentifierData propertyName, WebKit::NPVariantData propertyValueData) -> (bool returnValue) Delayed
- RemoveProperty(WebKit::NPIdentifierData propertyName) -> (bool returnValue) Delayed
- Enumerate() -> (bool returnValue, Vector<WebKit::NPIdentifierData> identifiersData) Delayed
- Construct(Vector<WebKit::NPVariantData> argumentsData) -> (bool returnValue, WebKit::NPVariantData resultData) Delayed
+ Deallocate() -> () Synchronous
+ HasMethod(WebKit::NPIdentifierData methodName) -> (bool returnValue) Synchronous
+ Invoke(WebKit::NPIdentifierData methodName, Vector<WebKit::NPVariantData> argumentsData) -> (bool returnValue, WebKit::NPVariantData resultData) Synchronous
+ InvokeDefault(Vector<WebKit::NPVariantData> argumentsData) -> (bool returnValue, WebKit::NPVariantData resultData) Synchronous
+ HasProperty(WebKit::NPIdentifierData propertyName) -> (bool returnValue) Synchronous
+ GetProperty(WebKit::NPIdentifierData propertyName) -> (bool returnValue, WebKit::NPVariantData resultData) Synchronous
+ SetProperty(WebKit::NPIdentifierData propertyName, WebKit::NPVariantData propertyValueData) -> (bool returnValue) Synchronous
+ RemoveProperty(WebKit::NPIdentifierData propertyName) -> (bool returnValue) Synchronous
+ Enumerate() -> (bool returnValue, Vector<WebKit::NPIdentifierData> identifiersData) Synchronous
+ Construct(Vector<WebKit::NPVariantData> argumentsData) -> (bool returnValue, WebKit::NPVariantData resultData) Synchronous
}
#endif
Modified: trunk/Source/WebKit/UIProcess/Cocoa/UserMediaCaptureManagerProxy.messages.in (243344 => 243345)
--- trunk/Source/WebKit/UIProcess/Cocoa/UserMediaCaptureManagerProxy.messages.in 2019-03-21 23:34:31 UTC (rev 243344)
+++ trunk/Source/WebKit/UIProcess/Cocoa/UserMediaCaptureManagerProxy.messages.in 2019-03-21 23:35:39 UTC (rev 243345)
@@ -24,11 +24,11 @@
#if ENABLE(MEDIA_STREAM)
messages -> UserMediaCaptureManagerProxy {
- CreateMediaSourceForCaptureDeviceWithConstraints(uint64_t id, WebCore::CaptureDevice device, String hashSalt, struct WebCore::MediaConstraints constraints) -> (bool success, String invalidConstraints, WebCore::RealtimeMediaSourceSettings settings) Delayed
+ CreateMediaSourceForCaptureDeviceWithConstraints(uint64_t id, WebCore::CaptureDevice device, String hashSalt, struct WebCore::MediaConstraints constraints) -> (bool success, String invalidConstraints, WebCore::RealtimeMediaSourceSettings settings) Synchronous
StartProducingData(uint64_t id)
StopProducingData(uint64_t id)
End(uint64_t id)
- Capabilities(uint64_t id) -> (WebCore::RealtimeMediaSourceCapabilities capabilities) Delayed
+ Capabilities(uint64_t id) -> (WebCore::RealtimeMediaSourceCapabilities capabilities) Synchronous
SetMuted(uint64_t id, bool muted)
ApplyConstraints(uint64_t id, struct WebCore::MediaConstraints constraints)
}
Modified: trunk/Source/WebKit/UIProcess/Plugins/PluginProcessProxy.messages.in (243344 => 243345)
--- trunk/Source/WebKit/UIProcess/Plugins/PluginProcessProxy.messages.in 2019-03-21 23:34:31 UTC (rev 243344)
+++ trunk/Source/WebKit/UIProcess/Plugins/PluginProcessProxy.messages.in 2019-03-21 23:35:39 UTC (rev 243345)
@@ -34,16 +34,16 @@
SetFullscreenWindowIsShowing(bool fullscreenWindowIsShowing)
# Returns true if the UI process launched the process.
- LaunchProcess(String launchPath, Vector<String> arguments) -> (bool result) Delayed
+ LaunchProcess(String launchPath, Vector<String> arguments) -> (bool result) Synchronous
# Returns true if the UI process launched the application.
- LaunchApplicationAtURL(String url, Vector<String> arguments) -> (bool result) Delayed
+ LaunchApplicationAtURL(String url, Vector<String> arguments) -> (bool result) Synchronous
# Returns true if the UI process did open the URL.
- OpenURL(String urlString) -> (bool result, int32_t status, String launchedURLString) Delayed
+ OpenURL(String urlString) -> (bool result, int32_t status, String launchedURLString) Synchronous
# Returns true if the UI process did open the file.
- OpenFile(String fullPath) -> (bool result) Delayed
+ OpenFile(String fullPath) -> (bool result) Synchronous
#endif
}
Modified: trunk/Source/WebKit/UIProcess/ProvisionalPageProxy.cpp (243344 => 243345)
--- trunk/Source/WebKit/UIProcess/ProvisionalPageProxy.cpp 2019-03-21 23:34:31 UTC (rev 243344)
+++ trunk/Source/WebKit/UIProcess/ProvisionalPageProxy.cpp 2019-03-21 23:35:39 UTC (rev 243345)
@@ -445,12 +445,12 @@
void ProvisionalPageProxy::didReceiveSyncMessage(IPC::Connection& connection, IPC::Decoder& decoder, std::unique_ptr<IPC::Encoder>& replyEncoder)
{
if (decoder.messageName() == Messages::WebPageProxy::BackForwardGoToItem::name()) {
- IPC::handleMessageDelayed<Messages::WebPageProxy::BackForwardGoToItem>(connection, decoder, replyEncoder, this, &ProvisionalPageProxy::backForwardGoToItem);
+ IPC::handleMessageSynchronous<Messages::WebPageProxy::BackForwardGoToItem>(connection, decoder, replyEncoder, this, &ProvisionalPageProxy::backForwardGoToItem);
return;
}
if (decoder.messageName() == Messages::WebPageProxy::DecidePolicyForNavigationActionSync::name()) {
- IPC::handleMessageDelayed<Messages::WebPageProxy::DecidePolicyForNavigationActionSync>(connection, decoder, replyEncoder, this, &ProvisionalPageProxy::decidePolicyForNavigationActionSync);
+ IPC::handleMessageSynchronous<Messages::WebPageProxy::DecidePolicyForNavigationActionSync>(connection, decoder, replyEncoder, this, &ProvisionalPageProxy::decidePolicyForNavigationActionSync);
return;
}
Modified: trunk/Source/WebKit/UIProcess/WebFullScreenManagerProxy.messages.in (243344 => 243345)
--- trunk/Source/WebKit/UIProcess/WebFullScreenManagerProxy.messages.in 2019-03-21 23:34:31 UTC (rev 243344)
+++ trunk/Source/WebKit/UIProcess/WebFullScreenManagerProxy.messages.in 2019-03-21 23:35:39 UTC (rev 243345)
@@ -22,7 +22,7 @@
#if ENABLE(FULLSCREEN_API)
messages -> WebFullScreenManagerProxy {
- SupportsFullScreen(bool withKeyboard) -> (bool supportsFullScreen) Delayed
+ SupportsFullScreen(bool withKeyboard) -> (bool supportsFullScreen) Synchronous
EnterFullScreen()
ExitFullScreen()
BeganEnterFullScreen(WebCore::IntRect initialRect, WebCore::IntRect finalRect)
Modified: trunk/Source/WebKit/UIProcess/WebPageProxy.messages.in (243344 => 243345)
--- trunk/Source/WebKit/UIProcess/WebPageProxy.messages.in 2019-03-21 23:34:31 UTC (rev 243344)
+++ trunk/Source/WebKit/UIProcess/WebPageProxy.messages.in 2019-03-21 23:35:39 UTC (rev 243345)
@@ -22,12 +22,12 @@
messages -> WebPageProxy {
# UI messages
- CreateNewPage(struct WebKit::FrameInfoData originatingFrameInfoData, uint64_t originatingPageID, WebCore::ResourceRequest request, struct WebCore::WindowFeatures windowFeatures, struct WebKit::NavigationActionData navigationActionData) -> (uint64_t newPageID, Optional<WebKit::WebPageCreationParameters> newPageParameters) Delayed
+ CreateNewPage(struct WebKit::FrameInfoData originatingFrameInfoData, uint64_t originatingPageID, WebCore::ResourceRequest request, struct WebCore::WindowFeatures windowFeatures, struct WebKit::NavigationActionData navigationActionData) -> (uint64_t newPageID, Optional<WebKit::WebPageCreationParameters> newPageParameters) Synchronous
ShowPage()
ClosePage(bool stopResponsivenessTimer)
- RunJavaScriptAlert(uint64_t frameID, struct WebCore::SecurityOriginData frameSecurityOrigin, String message) -> () Delayed
- RunJavaScriptConfirm(uint64_t frameID, struct WebCore::SecurityOriginData frameSecurityOrigin, String message) -> (bool result) Delayed
- RunJavaScriptPrompt(uint64_t frameID, struct WebCore::SecurityOriginData frameSecurityOrigin, String message, String defaultValue) -> (String result) Delayed
+ RunJavaScriptAlert(uint64_t frameID, struct WebCore::SecurityOriginData frameSecurityOrigin, String message) -> () Synchronous
+ RunJavaScriptConfirm(uint64_t frameID, struct WebCore::SecurityOriginData frameSecurityOrigin, String message) -> (bool result) Synchronous
+ RunJavaScriptPrompt(uint64_t frameID, struct WebCore::SecurityOriginData frameSecurityOrigin, String message, String defaultValue) -> (String result) Synchronous
MouseDidMoveOverElement(struct WebKit::WebHitTestResultData hitTestResultData, uint32_t modifiers, WebKit::UserData userData)
#if ENABLE(NETSCAPE_PLUGIN_API)
@@ -34,8 +34,8 @@
UnavailablePluginButtonClicked(uint32_t pluginUnavailabilityReason, String mimeType, String pluginURLString, String pluginspageAttributeURLString, String frameURLString, String pageURLString)
#endif // ENABLE(NETSCAPE_PLUGIN_API)
#if ENABLE(WEBGL)
- WebGLPolicyForURL(URL url) -> (uint32_t loadPolicy) Delayed
- ResolveWebGLPolicyForURL(URL url) -> (uint32_t loadPolicy) Delayed
+ WebGLPolicyForURL(URL url) -> (uint32_t loadPolicy) Synchronous
+ ResolveWebGLPolicyForURL(URL url) -> (uint32_t loadPolicy) Synchronous
#endif // ENABLE(WEBGL)
DidChangeViewportProperties(struct WebCore::ViewportAttributes attributes)
DidReceiveEvent(uint32_t type, bool handled)
@@ -51,18 +51,18 @@
FrameSetLargestFrameChanged(uint64_t frameID)
SetRenderTreeSize(uint64_t treeSize)
SetToolbarsAreVisible(bool toolbarsAreVisible)
- GetToolbarsAreVisible() -> (bool toolbarsAreVisible) Delayed
+ GetToolbarsAreVisible() -> (bool toolbarsAreVisible) Synchronous
SetMenuBarIsVisible(bool menuBarIsVisible)
- GetMenuBarIsVisible() -> (bool menuBarIsVisible) Delayed
+ GetMenuBarIsVisible() -> (bool menuBarIsVisible) Synchronous
SetStatusBarIsVisible(bool statusBarIsVisible)
- GetStatusBarIsVisible() -> (bool statusBarIsVisible) Delayed
+ GetStatusBarIsVisible() -> (bool statusBarIsVisible) Synchronous
SetIsResizable(bool isResizable)
SetWindowFrame(WebCore::FloatRect windowFrame)
- GetWindowFrame() -> (WebCore::FloatRect windowFrame) Delayed
- ScreenToRootView(WebCore::IntPoint screenPoint) -> (WebCore::IntPoint windowPoint) Delayed
- RootViewToScreen(WebCore::IntRect rect) -> (WebCore::IntRect screenFrame) Delayed
- AccessibilityScreenToRootView(WebCore::IntPoint screenPoint) -> (WebCore::IntPoint windowPoint) Delayed
- RootViewToAccessibilityScreen(WebCore::IntRect rect) -> (WebCore::IntRect screenFrame) Delayed
+ GetWindowFrame() -> (WebCore::FloatRect windowFrame) Synchronous
+ ScreenToRootView(WebCore::IntPoint screenPoint) -> (WebCore::IntPoint windowPoint) Synchronous
+ RootViewToScreen(WebCore::IntRect rect) -> (WebCore::IntRect screenFrame) Synchronous
+ AccessibilityScreenToRootView(WebCore::IntPoint screenPoint) -> (WebCore::IntPoint windowPoint) Synchronous
+ RootViewToAccessibilityScreen(WebCore::IntRect rect) -> (WebCore::IntRect screenFrame) Synchronous
#if PLATFORM(COCOA)
ShowValidationMessage(WebCore::IntRect anchorRect, String message)
@@ -69,11 +69,11 @@
HideValidationMessage()
#endif
- RunBeforeUnloadConfirmPanel(uint64_t frameID, struct WebCore::SecurityOriginData frameSecurityOrigin, String message) -> (bool shouldClose) Delayed
+ RunBeforeUnloadConfirmPanel(uint64_t frameID, struct WebCore::SecurityOriginData frameSecurityOrigin, String message) -> (bool shouldClose) Synchronous
PageDidScroll()
RunOpenPanel(uint64_t frameID, struct WebCore::SecurityOriginData frameSecurityOrigin, struct WebCore::FileChooserSettings parameters)
ShowShareSheet(struct WebCore::ShareDataWithParsedURL shareData, uint64_t callbackID)
- PrintFrame(uint64_t frameID) -> () Delayed
+ PrintFrame(uint64_t frameID) -> () Synchronous
RunModal()
NotifyScrollerThumbIsVisibleInRect(WebCore::IntRect scrollerThumb)
RecommendedScrollbarStyleDidChange(int32_t newStyle)
@@ -104,7 +104,7 @@
# Policy messages
DecidePolicyForResponse(uint64_t frameID, struct WebCore::SecurityOriginData frameSecurityOrigin, WebCore::PolicyCheckIdentifier policyCheckIdentifier, uint64_t navigationID, WebCore::ResourceResponse response, WebCore::ResourceRequest request, bool canShowMIMEType, uint64_t listenerID, WebKit::UserData userData)
DecidePolicyForNavigationActionAsync(uint64_t frameID, struct WebCore::SecurityOriginData frameSecurityOrigin, WebCore::PolicyCheckIdentifier policyCheckIdentifier, uint64_t navigationID, struct WebKit::NavigationActionData navigationActionData, struct WebKit::FrameInfoData originatingFrameInfoData, uint64_t originatingPageID, WebCore::ResourceRequest originalRequest, WebCore::ResourceRequest request, IPC::FormDataReference requestBody, WebCore::ResourceResponse redirectResponse, WebKit::UserData userData, uint64_t listenerID)
- DecidePolicyForNavigationActionSync(uint64_t frameID, bool isMainFrame, struct WebCore::SecurityOriginData frameSecurityOrigin, WebCore::PolicyCheckIdentifier policyCheckIdentifier, uint64_t navigationID, struct WebKit::NavigationActionData navigationActionData, struct WebKit::FrameInfoData originatingFrameInfoData, uint64_t originatingPageID, WebCore::ResourceRequest originalRequest, WebCore::ResourceRequest request, IPC::FormDataReference requestBody, WebCore::ResourceResponse redirectResponse, WebKit::UserData userData) -> (WebCore::PolicyCheckIdentifier policyCheckIdentifier, enum:uint8_t WebCore::PolicyAction policyAction, uint64_t newNavigationID, WebKit::DownloadID downloadID, Optional<WebKit::WebsitePoliciesData> websitePolicies) Delayed
+ DecidePolicyForNavigationActionSync(uint64_t frameID, bool isMainFrame, struct WebCore::SecurityOriginData frameSecurityOrigin, WebCore::PolicyCheckIdentifier policyCheckIdentifier, uint64_t navigationID, struct WebKit::NavigationActionData navigationActionData, struct WebKit::FrameInfoData originatingFrameInfoData, uint64_t originatingPageID, WebCore::ResourceRequest originalRequest, WebCore::ResourceRequest request, IPC::FormDataReference requestBody, WebCore::ResourceResponse redirectResponse, WebKit::UserData userData) -> (WebCore::PolicyCheckIdentifier policyCheckIdentifier, enum:uint8_t WebCore::PolicyAction policyAction, uint64_t newNavigationID, WebKit::DownloadID downloadID, Optional<WebKit::WebsitePoliciesData> websitePolicies) Synchronous
DecidePolicyForNewWindowAction(uint64_t frameID, struct WebCore::SecurityOriginData frameSecurityOrigin, WebCore::PolicyCheckIdentifier policyCheckIdentifier, struct WebKit::NavigationActionData navigationActionData, WebCore::ResourceRequest request, String frameName, uint64_t listenerID, WebKit::UserData userData)
UnableToImplementPolicy(uint64_t frameID, WebCore::ResourceError error, WebKit::UserData userData)
@@ -143,7 +143,7 @@
DidChangeMainDocument(uint64_t frameID);
DidDestroyNavigation(uint64_t navigationID)
- HasInsecureContent() -> (enum:bool WebCore::HasInsecureContent hasInsecureContent) Delayed
+ HasInsecureContent() -> (enum:bool WebCore::HasInsecureContent hasInsecureContent) Synchronous
MainFramePluginHandlesPageScaleGestureDidChange(bool mainFramePluginHandlesPageScaleGesture)
@@ -187,7 +187,7 @@
AutocorrectionDataCallback(Vector<WebCore::FloatRect> textRects, String fontName, double fontSize, uint64_t traits, WebKit::CallbackID callbackID)
AutocorrectionContextCallback(struct WebKit::WebAutocorrectionContext context, WebKit::CallbackID callbackID)
SelectionContextCallback(String selectedText, String beforeText, String afterText, WebKit::CallbackID callbackID)
- InterpretKeyEvent(struct WebKit::EditorState state, bool isCharEvent) -> (bool handled) Delayed
+ InterpretKeyEvent(struct WebKit::EditorState state, bool isCharEvent) -> (bool handled) Synchronous
DidReceivePositionInformation(struct WebKit::InteractionInformationAtPosition information)
SaveImageToLibrary(WebKit::SharedMemory::Handle handle, uint64_t size)
ShowPlaybackTargetPicker(bool hasVideo, WebCore::IntRect elementRect, enum:uint8_t WebCore::RouteSharingPolicy policy, String routingContextUID)
@@ -223,10 +223,10 @@
# BackForward messages
BackForwardAddItem(struct WebKit::BackForwardListItemState itemState)
- BackForwardGoToItem(struct WebCore::BackForwardItemIdentifier itemID) -> (WebKit::SandboxExtension::Handle sandboxExtensionHandle) Delayed
- BackForwardItemAtIndex(int32_t itemIndex) -> (Optional<WebCore::BackForwardItemIdentifier> itemID) Delayed
- BackForwardBackListCount() -> (uint32_t count) Delayed
- BackForwardForwardListCount() -> (uint32_t count) Delayed
+ BackForwardGoToItem(struct WebCore::BackForwardItemIdentifier itemID) -> (WebKit::SandboxExtension::Handle sandboxExtensionHandle) Synchronous
+ BackForwardItemAtIndex(int32_t itemIndex) -> (Optional<WebCore::BackForwardItemIdentifier> itemID) Synchronous
+ BackForwardBackListCount() -> (uint32_t count) Synchronous
+ BackForwardForwardListCount() -> (uint32_t count) Synchronous
BackForwardClear()
WillGoToBackForwardListItem(struct WebCore::BackForwardItemIdentifier itemID, bool inPageCache)
@@ -234,8 +234,8 @@
RegisterEditCommandForUndo(uint64_t commandID, String label)
ClearAllEditCommands()
RegisterInsertionUndoGrouping()
- CanUndoRedo(enum:bool WebKit::UndoOrRedo undoOrRedo) -> (bool result) Delayed
- ExecuteUndoRedo(enum:bool WebKit::UndoOrRedo undoOrRedo) -> () Delayed
+ CanUndoRedo(enum:bool WebKit::UndoOrRedo undoOrRedo) -> (bool result) Synchronous
+ ExecuteUndoRedo(enum:bool WebKit::UndoOrRedo undoOrRedo) -> () Synchronous
# Diagnostic messages logging
LogDiagnosticMessage(String message, String description, enum:bool WebCore::ShouldSample shouldSample)
@@ -252,7 +252,7 @@
SetHasHadSelectionChangesFromUserInteraction(bool hasHadUserSelectionChanges)
SetIsTouchBarUpdateSupressedForHiddenContentEditable(bool isTouchBarUpdateSupressed)
SetIsNeverRichlyEditableForTouchBar(bool isNeverRichlyEditable)
- RequestDOMPasteAccess(WebCore::IntRect elementRect, String originIdentifier) -> (enum:uint8_t WebCore::DOMPasteAccessResponse response) Delayed
+ RequestDOMPasteAccess(WebCore::IntRect elementRect, String originIdentifier) -> (enum:uint8_t WebCore::DOMPasteAccessResponse response) Synchronous
# Find messages
DidCountStringMatches(String string, uint32_t matchCount)
@@ -272,10 +272,10 @@
#endif
# Database messages
- ExceededDatabaseQuota(uint64_t frameID, String originIdentifier, String databaseName, String databaseDisplayName, uint64_t currentQuota, uint64_t currentOriginUsage, uint64_t currentDatabaseUsage, uint64_t expectedUsage) -> (uint64_t newQuota) Delayed
+ ExceededDatabaseQuota(uint64_t frameID, String originIdentifier, String databaseName, String databaseDisplayName, uint64_t currentQuota, uint64_t currentOriginUsage, uint64_t currentDatabaseUsage, uint64_t expectedUsage) -> (uint64_t newQuota) Synchronous
# Application cache messages
- ReachedApplicationCacheOriginQuota(String originIdentifier, uint64_t currentQuota, uint64_t totalBytesNeeded) -> (uint64_t newQuota) Delayed
+ ReachedApplicationCacheOriginQuota(String originIdentifier, uint64_t currentQuota, uint64_t totalBytesNeeded) -> (uint64_t newQuota) Synchronous
# Geolocation messages
RequestGeolocationPermissionForFrame(uint64_t geolocationID, uint64_t frameID, String originIdentifier)
@@ -296,14 +296,14 @@
# Spelling and grammar messages
#if USE(UNIFIED_TEXT_CHECKING)
- CheckTextOfParagraph(String text, OptionSet<WebCore::TextCheckingType> checkingTypes, int32_t insertionPoint) -> (Vector<WebCore::TextCheckingResult> results) Delayed
+ CheckTextOfParagraph(String text, OptionSet<WebCore::TextCheckingType> checkingTypes, int32_t insertionPoint) -> (Vector<WebCore::TextCheckingResult> results) Synchronous
#endif
- CheckSpellingOfString(String text) -> (int32_t misspellingLocation, int32_t misspellingLength) Delayed
- CheckGrammarOfString(String text) -> (Vector<WebCore::GrammarDetail> results, int32_t badGrammarLocation, int32_t badGrammarLength) Delayed
- SpellingUIIsShowing() -> (bool isShowing) Delayed
+ CheckSpellingOfString(String text) -> (int32_t misspellingLocation, int32_t misspellingLength) Synchronous
+ CheckGrammarOfString(String text) -> (Vector<WebCore::GrammarDetail> results, int32_t badGrammarLocation, int32_t badGrammarLength) Synchronous
+ SpellingUIIsShowing() -> (bool isShowing) Synchronous
UpdateSpellingUIWithMisspelledWord(String misspelledWord)
UpdateSpellingUIWithGrammarString(String badGrammarPhrase, struct WebCore::GrammarDetail grammarDetail)
- GetGuessesForWord(String word, String context, int32_t insertionPoint) -> (Vector<String> guesses) Delayed
+ GetGuessesForWord(String word, String context, int32_t insertionPoint) -> (Vector<String> guesses) Synchronous
LearnWord(String word)
IgnoreWord(String word)
RequestCheckingOfString(uint64_t requestID, WebCore::TextCheckingRequestData request, int32_t insertionPoint)
@@ -336,7 +336,7 @@
DidPerformDictionaryLookup(struct WebCore::DictionaryPopupInfo dictionaryPopupInfo)
# Keyboard input support messages
- ExecuteSavedCommandBySelector(String selector) -> (bool handled) Delayed
+ ExecuteSavedCommandBySelector(String selector) -> (bool handled) Synchronous
# Remote accessibility messages
RegisterWebProcessAccessibilityToken(IPC::DataReference data)
@@ -346,7 +346,7 @@
SetPluginComplexTextInputState(uint64_t pluginComplexTextInputIdentifier, uint64_t complexTextInputState)
# Speech messages
- GetIsSpeaking() -> (bool isSpeaking) Delayed
+ GetIsSpeaking() -> (bool isSpeaking) Synchronous
Speak(String string)
StopSpeaking()
@@ -364,7 +364,7 @@
#endif
#if USE(APPKIT)
- SubstitutionsPanelIsShowing() -> (bool isShowing) Delayed
+ SubstitutionsPanelIsShowing() -> (bool isShowing) Synchronous
#endif
#if USE(AUTOMATIC_TEXT_REPLACEMENT)
toggleSmartInsertDelete()
@@ -377,7 +377,7 @@
# Autocorrection messages
ShowCorrectionPanel(int32_t panelType, WebCore::FloatRect boundingBoxOfReplacedString, String replacedString, String replacementString, Vector<String> alternativeReplacementStrings)
DismissCorrectionPanel(int32_t reason)
- DismissCorrectionPanelSoon(int32_t reason) -> (String result) Delayed
+ DismissCorrectionPanelSoon(int32_t reason) -> (String result) Synchronous
RecordAutocorrectionResponse(int32_t response, String replacedString, String replacementString);
SetEditableElementIsFocused(bool editableElementIsFocused)
@@ -386,12 +386,12 @@
#if USE(DICTATION_ALTERNATIVES)
ShowDictationAlternativeUI(WebCore::FloatRect boundingBoxOfDictatedText, uint64_t dictationContext)
RemoveDictationAlternatives(uint64_t dictationContext)
- DictationAlternatives(uint64_t dictationContext) -> (Vector<String> alternatives) Delayed
+ DictationAlternatives(uint64_t dictationContext) -> (Vector<String> alternatives) Synchronous
#endif
#if PLATFORM(X11)
# X11 windowed plugin messages
- CreatePluginContainer() -> (uint64_t windowID) Delayed
+ CreatePluginContainer() -> (uint64_t windowID) Synchronous
WindowedPluginGeometryDidChange(WebCore::IntRect frameRect, WebCore::IntRect clipRect, uint64_t windowID)
WindowedPluginVisibilityDidChange(bool isVisible, uint64_t windowID)
#endif
@@ -429,7 +429,7 @@
# Search popup menus
SaveRecentSearches(String name, Vector<WebCore::RecentSearch> searchItems)
- LoadRecentSearches(String name) -> (Vector<WebCore::RecentSearch> result) Delayed
+ LoadRecentSearches(String name) -> (Vector<WebCore::RecentSearch> result) Synchronous
SavePDFToFileInDownloadsFolder(String suggestedFilename, URL originatingURL, IPC::DataReference data)
@@ -439,11 +439,11 @@
#endif
#if ENABLE(PDFKIT_PLUGIN)
- ShowPDFContextMenu(struct WebKit::PDFContextMenu contextMenu) -> (Optional<int32_t> selectedItem) Delayed
+ ShowPDFContextMenu(struct WebKit::PDFContextMenu contextMenu) -> (Optional<int32_t> selectedItem) Synchronous
#endif
#if ENABLE(NETSCAPE_PLUGIN_API)
- FindPlugin(String mimeType, uint32_t processType, String urlString, String frameURLString, String pageURLString, bool allowOnlyApplicationPlugins) -> (uint64_t pluginProcessToken, String newMIMEType, uint32_t pluginLoadPolicy, String unavailabilityDescription, bool isUnsupported) Delayed
+ FindPlugin(String mimeType, uint32_t processType, String urlString, String frameURLString, String pageURLString, bool allowOnlyApplicationPlugins) -> (uint64_t pluginProcessToken, String newMIMEType, uint32_t pluginLoadPolicy, String unavailabilityDescription, bool isUnsupported) Synchronous
#endif
DidUpdateActivityState()
@@ -451,8 +451,8 @@
DidSaveToPageCache()
#if ENABLE(WEB_CRYPTO)
- WrapCryptoKey(Vector<uint8_t> key) -> (bool succeeded, Vector<uint8_t> wrappedKey) Delayed
- UnwrapCryptoKey(Vector<uint8_t> wrappedKey) -> (bool succeeded, Vector<uint8_t> key) Delayed
+ WrapCryptoKey(Vector<uint8_t> key) -> (bool succeeded, Vector<uint8_t> wrappedKey) Synchronous
+ UnwrapCryptoKey(Vector<uint8_t> wrappedKey) -> (bool succeeded, Vector<uint8_t> key) Synchronous
#endif
@@ -485,7 +485,7 @@
DidPerformImmediateActionHitTest(struct WebKit::WebHitTestResultData result, bool contentPreventsDefault, WebKit::UserData userData)
#endif
HandleMessage(String messageName, WebKit::UserData messageBody) WantsConnection
- HandleSynchronousMessage(String messageName, WebKit::UserData messageBody) -> (WebKit::UserData returnData) Delayed WantsConnection
+ HandleSynchronousMessage(String messageName, WebKit::UserData messageBody) -> (WebKit::UserData returnData) Synchronous WantsConnection
HandleAutoFillButtonClick(WebKit::UserData userData)
@@ -532,7 +532,7 @@
StartURLSchemeTask(struct WebKit::URLSchemeTaskParameters parameters)
StopURLSchemeTask(uint64_t handlerIdentifier, uint64_t taskIdentifier)
- LoadSynchronousURLSchemeTask(struct WebKit::URLSchemeTaskParameters parameters) -> (WebCore::ResourceResponse response, WebCore::ResourceError error, IPC::DataReference data) Delayed
+ LoadSynchronousURLSchemeTask(struct WebKit::URLSchemeTaskParameters parameters) -> (WebCore::ResourceResponse response, WebCore::ResourceError error, IPC::DataReference data) Synchronous
#if ENABLE(DEVICE_ORIENTATION)
RequestDeviceOrientationAndMotionAccess(uint64_t frameID, struct WebCore::SecurityOriginData origin) -> (bool granted) Async
@@ -546,13 +546,13 @@
CloneAttachmentData(String fromIdentifier, String toIdentifier)
DidInsertAttachmentWithIdentifier(String identifier, String source, bool hasEnclosingImage)
DidRemoveAttachmentWithIdentifier(String identifier)
- SerializedAttachmentDataForIdentifiers(Vector<String> identifiers) -> (Vector<WebCore::SerializedAttachmentData> seralizedData) Delayed
+ SerializedAttachmentDataForIdentifiers(Vector<String> identifiers) -> (Vector<WebCore::SerializedAttachmentData> seralizedData) Synchronous
#endif
- SignedPublicKeyAndChallengeString(unsigned keySizeIndex, String challengeString, URL url) -> (String result) Delayed
+ SignedPublicKeyAndChallengeString(unsigned keySizeIndex, String challengeString, URL url) -> (String result) Synchronous
#if ENABLE(SPEECH_SYNTHESIS)
- SpeechSynthesisVoiceList() -> (Vector<WebKit::WebSpeechSynthesisVoice> voiceList) Delayed
+ SpeechSynthesisVoiceList() -> (Vector<WebKit::WebSpeechSynthesisVoice> voiceList) Synchronous
SpeechSynthesisSpeak(String text, String lang, float volume, float rate, float pitch, MonotonicTime startTime, String voiceURI, String voiceName, String voiceLang, bool localService, bool defaultVoice) -> () Async
SpeechSynthesisCancel()
SpeechSynthesisPause() -> () Async
Modified: trunk/Source/WebKit/UIProcess/WebPasteboardProxy.messages.in (243344 => 243345)
--- trunk/Source/WebKit/UIProcess/WebPasteboardProxy.messages.in 2019-03-21 23:34:31 UTC (rev 243344)
+++ trunk/Source/WebKit/UIProcess/WebPasteboardProxy.messages.in 2019-03-21 23:35:39 UTC (rev 243345)
@@ -26,47 +26,47 @@
WriteWebContentToPasteboard(struct WebCore::PasteboardWebContent content, String pasteboardName)
WriteImageToPasteboard(struct WebCore::PasteboardImage pasteboardImage, String pasteboardName)
WriteStringToPasteboard(String pasteboardType, String text, String pasteboardName)
- ReadStringFromPasteboard(uint64_t index, String pasteboardType, String pasteboardName) -> (String string) Delayed
- ReadURLFromPasteboard(uint64_t index, String pasteboardName) -> (String url, String title) Delayed
- ReadBufferFromPasteboard(uint64_t index, String pasteboardType, String pasteboardName) -> (WebKit::SharedMemory::Handle handle, uint64_t size) Delayed
- GetPasteboardItemsCount(String pasteboardName) -> (uint64_t itemsCount) Delayed
- AllPasteboardItemInfo(String pasteboardName) -> (Vector<WebCore::PasteboardItemInfo> allInfo) Delayed
- InformationForItemAtIndex(uint64_t index, String pasteboardName) -> (struct WebCore::PasteboardItemInfo info) Delayed
+ ReadStringFromPasteboard(uint64_t index, String pasteboardType, String pasteboardName) -> (String string) Synchronous
+ ReadURLFromPasteboard(uint64_t index, String pasteboardName) -> (String url, String title) Synchronous
+ ReadBufferFromPasteboard(uint64_t index, String pasteboardType, String pasteboardName) -> (WebKit::SharedMemory::Handle handle, uint64_t size) Synchronous
+ GetPasteboardItemsCount(String pasteboardName) -> (uint64_t itemsCount) Synchronous
+ AllPasteboardItemInfo(String pasteboardName) -> (Vector<WebCore::PasteboardItemInfo> allInfo) Synchronous
+ InformationForItemAtIndex(uint64_t index, String pasteboardName) -> (struct WebCore::PasteboardItemInfo info) Synchronous
UpdateSupportedTypeIdentifiers(Vector<String> identifiers, String pasteboardName)
#endif
- WriteCustomData(struct WebCore::PasteboardCustomData data, String pasteboardName) -> (uint64_t changeCount) Delayed
- TypesSafeForDOMToReadAndWrite(String pasteboardName, String origin) -> (Vector<String> types) Delayed
+ WriteCustomData(struct WebCore::PasteboardCustomData data, String pasteboardName) -> (uint64_t changeCount) Synchronous
+ TypesSafeForDOMToReadAndWrite(String pasteboardName, String origin) -> (Vector<String> types) Synchronous
#if PLATFORM(COCOA)
# Pasteboard messages.
- GetNumberOfFiles(String pasteboardName) -> (uint64_t numberOfFiles) Delayed
- GetPasteboardTypes(String pasteboardName) -> (Vector<String> types) Delayed
- GetPasteboardPathnamesForType(String pasteboardName, String pasteboardType) -> (Vector<String> pathnames, WebKit::SandboxExtension::HandleArray sandboxExtensions) Delayed WantsConnection
- GetPasteboardStringForType(String pasteboardName, String pasteboardType) -> (String string) Delayed
- GetPasteboardStringsForType(String pasteboardName, String pasteboardType) -> (Vector<String> strings) Delayed
- GetPasteboardBufferForType(String pasteboardName, String pasteboardType) -> (WebKit::SharedMemory::Handle handle, uint64_t size) Delayed
- PasteboardCopy(String fromPasteboard, String toPasteboard) -> (uint64_t changeCount) Delayed
- GetPasteboardChangeCount(String pasteboardName) -> (uint64_t changeCount) Delayed
- GetPasteboardUniqueName() -> (String pasteboardName) Delayed
- GetPasteboardColor(String pasteboardName) -> (WebCore::Color color) Delayed
- GetPasteboardURL(String pasteboardName) -> (String urlString) Delayed
- AddPasteboardTypes(String pasteboardName, Vector<String> pasteboardTypes) -> (uint64_t changeCount) Delayed
- SetPasteboardTypes(String pasteboardName, Vector<String> pasteboardTypes) -> (uint64_t changeCount) Delayed
- SetPasteboardURL(struct WebCore::PasteboardURL pasteboardURL, String pasteboardName) -> (uint64_t changeCount) Delayed WantsConnection
- SetPasteboardColor(String pasteboardName, WebCore::Color color) -> (uint64_t changeCount) Delayed
- SetPasteboardStringForType(String pasteboardName, String pasteboardType, String string) -> (uint64_t changeCount) Delayed
- SetPasteboardBufferForType(String pasteboardName, String pasteboardType, WebKit::SharedMemory::Handle handle, uint64_t size) -> (uint64_t changeCount) Delayed
+ GetNumberOfFiles(String pasteboardName) -> (uint64_t numberOfFiles) Synchronous
+ GetPasteboardTypes(String pasteboardName) -> (Vector<String> types) Synchronous
+ GetPasteboardPathnamesForType(String pasteboardName, String pasteboardType) -> (Vector<String> pathnames, WebKit::SandboxExtension::HandleArray sandboxExtensions) Synchronous WantsConnection
+ GetPasteboardStringForType(String pasteboardName, String pasteboardType) -> (String string) Synchronous
+ GetPasteboardStringsForType(String pasteboardName, String pasteboardType) -> (Vector<String> strings) Synchronous
+ GetPasteboardBufferForType(String pasteboardName, String pasteboardType) -> (WebKit::SharedMemory::Handle handle, uint64_t size) Synchronous
+ PasteboardCopy(String fromPasteboard, String toPasteboard) -> (uint64_t changeCount) Synchronous
+ GetPasteboardChangeCount(String pasteboardName) -> (uint64_t changeCount) Synchronous
+ GetPasteboardUniqueName() -> (String pasteboardName) Synchronous
+ GetPasteboardColor(String pasteboardName) -> (WebCore::Color color) Synchronous
+ GetPasteboardURL(String pasteboardName) -> (String urlString) Synchronous
+ AddPasteboardTypes(String pasteboardName, Vector<String> pasteboardTypes) -> (uint64_t changeCount) Synchronous
+ SetPasteboardTypes(String pasteboardName, Vector<String> pasteboardTypes) -> (uint64_t changeCount) Synchronous
+ SetPasteboardURL(struct WebCore::PasteboardURL pasteboardURL, String pasteboardName) -> (uint64_t changeCount) Synchronous WantsConnection
+ SetPasteboardColor(String pasteboardName, WebCore::Color color) -> (uint64_t changeCount) Synchronous
+ SetPasteboardStringForType(String pasteboardName, String pasteboardType, String string) -> (uint64_t changeCount) Synchronous
+ SetPasteboardBufferForType(String pasteboardName, String pasteboardType, WebKit::SharedMemory::Handle handle, uint64_t size) -> (uint64_t changeCount) Synchronous
#endif
#if PLATFORM(GTK)
WriteToClipboard(String pasteboardName, struct WebKit::WebSelectionData pasteboardContent)
- ReadFromClipboard(String pasteboardName) -> (struct WebKit::WebSelectionData pasteboardContent) Delayed
+ ReadFromClipboard(String pasteboardName) -> (struct WebKit::WebSelectionData pasteboardContent) Synchronous
#endif
#if USE(LIBWPE)
- GetPasteboardTypes() -> (Vector<String> types) Delayed
- ReadStringFromPasteboard(uint64_t index, String pasteboardType) -> (String string) Delayed
+ GetPasteboardTypes() -> (Vector<String> types) Synchronous
+ ReadStringFromPasteboard(uint64_t index, String pasteboardType) -> (String string) Synchronous
WriteWebContentToPasteboard(struct WebCore::PasteboardWebContent content)
WriteStringToPasteboard(String pasteboardType, String text)
#endif
Modified: trunk/Source/WebKit/UIProcess/WebProcessPool.messages.in (243344 => 243345)
--- trunk/Source/WebKit/UIProcess/WebProcessPool.messages.in 2019-03-21 23:34:31 UTC (rev 243344)
+++ trunk/Source/WebKit/UIProcess/WebProcessPool.messages.in 2019-03-21 23:35:39 UTC (rev 243345)
@@ -22,7 +22,7 @@
messages -> WebProcessPool {
HandleMessage(String messageName, WebKit::UserData messageBody) WantsConnection
- HandleSynchronousMessage(String messageName, WebKit::UserData messageBody) -> (WebKit::UserData returnData) Delayed WantsConnection
+ HandleSynchronousMessage(String messageName, WebKit::UserData messageBody) -> (WebKit::UserData returnData) Synchronous WantsConnection
DidGetStatistics(struct WebKit::StatisticsData statisticsData, uint64_t callbackID)
Modified: trunk/Source/WebKit/UIProcess/WebProcessProxy.messages.in (243344 => 243345)
--- trunk/Source/WebKit/UIProcess/WebProcessProxy.messages.in 2019-03-21 23:34:31 UTC (rev 243344)
+++ trunk/Source/WebKit/UIProcess/WebProcessProxy.messages.in 2019-03-21 23:35:39 UTC (rev 243345)
@@ -26,7 +26,7 @@
DidDestroyUserGestureToken(uint64_t userGestureTokenID)
- ShouldTerminate() -> (bool shouldTerminate) Delayed
+ ShouldTerminate() -> (bool shouldTerminate) Synchronous
EnableSuddenTermination()
DisableSuddenTermination()
@@ -33,10 +33,10 @@
# Plugin messages.
#if ENABLE(NETSCAPE_PLUGIN_API)
- GetPlugins(bool refresh) -> (Vector<WebCore::PluginInfo> plugins, Vector<WebCore::PluginInfo> applicationPlugins, struct Optional<Vector<WebCore::SupportedPluginIdentifier>> supportedPluginIdentifiers) Delayed
- GetPluginProcessConnection(uint64_t pluginProcessToken) -> (IPC::Attachment connectionHandle, bool supportsAsynchronousInitialization) Delayed
+ GetPlugins(bool refresh) -> (Vector<WebCore::PluginInfo> plugins, Vector<WebCore::PluginInfo> applicationPlugins, struct Optional<Vector<WebCore::SupportedPluginIdentifier>> supportedPluginIdentifiers) Synchronous
+ GetPluginProcessConnection(uint64_t pluginProcessToken) -> (IPC::Attachment connectionHandle, bool supportsAsynchronousInitialization) Synchronous
#endif
- GetNetworkProcessConnection() -> (IPC::Attachment connectionHandle) Delayed
+ GetNetworkProcessConnection() -> (IPC::Attachment connectionHandle) Synchronous
ProcessReadyToSuspend()
DidCancelProcessSuspension()
Modified: trunk/Source/WebKit/UIProcess/WebStorage/StorageManager.messages.in (243344 => 243345)
--- trunk/Source/WebKit/UIProcess/WebStorage/StorageManager.messages.in 2019-03-21 23:34:31 UTC (rev 243344)
+++ trunk/Source/WebKit/UIProcess/WebStorage/StorageManager.messages.in 2019-03-21 23:35:39 UTC (rev 243345)
@@ -26,7 +26,7 @@
CreateSessionStorageMap(uint64_t storageMapID, uint64_t storageNamespaceID, struct WebCore::SecurityOriginData securityOriginData) WantsConnection
DestroyStorageMap(uint64_t storageMapID) WantsConnection
- GetValues(struct WebCore::SecurityOriginData securityOriginData, uint64_t storageMapID, uint64_t storageMapSeed) -> (HashMap<String, String> values) Delayed WantsConnection
+ GetValues(struct WebCore::SecurityOriginData securityOriginData, uint64_t storageMapID, uint64_t storageMapSeed) -> (HashMap<String, String> values) Synchronous WantsConnection
SetItem(struct WebCore::SecurityOriginData securityOriginData, uint64_t storageMapID, uint64_t sourceStorageAreaID, uint64_t storageMapSeed, String key, String value, String urlString) WantsConnection
RemoveItem(struct WebCore::SecurityOriginData securityOriginData, uint64_t storageMapID, uint64_t sourceStorageAreaID, uint64_t storageMapSeed, String key, String urlString) WantsConnection
Modified: trunk/Source/WebKit/UIProcess/mac/SecItemShimProxy.messages.in (243344 => 243345)
--- trunk/Source/WebKit/UIProcess/mac/SecItemShimProxy.messages.in 2019-03-21 23:34:31 UTC (rev 243344)
+++ trunk/Source/WebKit/UIProcess/mac/SecItemShimProxy.messages.in 2019-03-21 23:35:39 UTC (rev 243345)
@@ -23,7 +23,7 @@
messages -> SecItemShimProxy {
#if ENABLE(SEC_ITEM_SHIM)
- SecItemRequest(WebKit::SecItemRequestData request) -> (WebKit::SecItemResponseData response) Delayed
+ SecItemRequest(WebKit::SecItemRequestData request) -> (WebKit::SecItemResponseData response) Synchronous
#endif
}
Modified: trunk/Source/WebKit/WebProcess/Plugins/PluginProcessConnection.messages.in (243344 => 243345)
--- trunk/Source/WebKit/WebProcess/Plugins/PluginProcessConnection.messages.in 2019-03-21 23:34:31 UTC (rev 243344)
+++ trunk/Source/WebKit/WebProcess/Plugins/PluginProcessConnection.messages.in 2019-03-21 23:35:39 UTC (rev 243345)
@@ -24,7 +24,7 @@
messages -> PluginProcessConnection LegacyReceiver {
# Set a global _javascript_ exception.
- SetException(String exceptionString) -> () Delayed
+ SetException(String exceptionString) -> () Synchronous
}
#endif
Modified: trunk/Source/WebKit/WebProcess/Plugins/PluginProxy.messages.in (243344 => 243345)
--- trunk/Source/WebKit/WebProcess/Plugins/PluginProxy.messages.in 2019-03-21 23:34:31 UTC (rev 243344)
+++ trunk/Source/WebKit/WebProcess/Plugins/PluginProxy.messages.in 2019-03-21 23:35:39 UTC (rev 243345)
@@ -30,22 +30,22 @@
Update(WebCore::IntRect paintedRect)
# Returns a PAC style string with proxies for the given URL.
- ProxiesForURL(String urlString) -> (String proxiesString) Delayed
+ ProxiesForURL(String urlString) -> (String proxiesString) Synchronous
# Returns the cookies for the given URL.
- CookiesForURL(String urlString) -> (String cookieString) Delayed
+ CookiesForURL(String urlString) -> (String cookieString) Synchronous
# Sets the cookies for the given URL.
SetCookiesForURL(String urlString, String cookieString)
# Gets the authentication info for the given protection space.
- GetAuthenticationInfo(WebCore::ProtectionSpace protectionSpace) -> (bool returnValue, String username, String password) Delayed
+ GetAuthenticationInfo(WebCore::ProtectionSpace protectionSpace) -> (bool returnValue, String username, String password) Synchronous
# Gets a reference to the plug-in element NPObject.
- GetPluginElementNPObject() -> (uint64_t pluginElementNPObjectID) Delayed
+ GetPluginElementNPObject() -> (uint64_t pluginElementNPObjectID) Synchronous
# Evaluates the given _javascript_ string.
- Evaluate(WebKit::NPVariantData npObjectAsVariantData, String scriptString, bool allowPopups) -> (bool returnValue, WebKit::NPVariantData resultData) Delayed
+ Evaluate(WebKit::NPVariantData npObjectAsVariantData, String scriptString, bool allowPopups) -> (bool returnValue, WebKit::NPVariantData resultData) Synchronous
# Cancels the given stream load.
CancelStreamLoad(uint64_t streamID)
@@ -72,7 +72,7 @@
#if PLATFORM(X11)
# Create the plugin container for windowed plugins
- CreatePluginContainer() -> (uint64_t windowID) Delayed
+ CreatePluginContainer() -> (uint64_t windowID) Synchronous
# Update geometry of windowed plugin widget
WindowedPluginGeometryDidChange(WebCore::IntRect frameRect, WebCore::IntRect clipRect, uint64_t windowID)
@@ -82,10 +82,10 @@
#endif
# Tells the WebProcess that the plug-in was successfully initialized asynchronously
- DidCreatePlugin(bool wantsWheelEvents, uint32_t remoteLayerClientID) -> () Delayed
+ DidCreatePlugin(bool wantsWheelEvents, uint32_t remoteLayerClientID) -> () Synchronous
# Tells the WebProcess that the plug-in failed to initialize.
- DidFailToCreatePlugin() -> () Delayed
+ DidFailToCreatePlugin() -> () Synchronous
# Tells the WebProcess that the plug-in has started or stopped playing audio.
SetPluginIsPlayingAudio(bool pluginIsPlayingAudio)
Modified: trunk/Source/WebKit/WebProcess/Storage/WebSWClientConnection.cpp (243344 => 243345)
--- trunk/Source/WebKit/WebProcess/Storage/WebSWClientConnection.cpp 2019-03-21 23:34:31 UTC (rev 243344)
+++ trunk/Source/WebKit/WebProcess/Storage/WebSWClientConnection.cpp 2019-03-21 23:35:39 UTC (rev 243345)
@@ -233,7 +233,7 @@
void WebSWClientConnection::syncTerminateWorker(ServiceWorkerIdentifier identifier)
{
- sendSync(Messages::WebSWServerConnection::SyncTerminateWorker(identifier), Messages::WebSWServerConnection::SyncTerminateWorker::Reply());
+ sendSync(Messages::WebSWServerConnection::SyncTerminateWorkerFromClient(identifier), Messages::WebSWServerConnection::SyncTerminateWorkerFromClient::Reply());
}
} // namespace WebKit
Modified: trunk/Source/WebKit/WebProcess/Storage/WebSWContextManagerConnection.messages.in (243344 => 243345)
--- trunk/Source/WebKit/WebProcess/Storage/WebSWContextManagerConnection.messages.in 2019-03-21 23:34:31 UTC (rev 243344)
+++ trunk/Source/WebKit/WebProcess/Storage/WebSWContextManagerConnection.messages.in 2019-03-21 23:35:39 UTC (rev 243345)
@@ -31,7 +31,7 @@
FireInstallEvent(WebCore::ServiceWorkerIdentifier identifier)
FireActivateEvent(WebCore::ServiceWorkerIdentifier identifier)
TerminateWorker(WebCore::ServiceWorkerIdentifier identifier)
- SyncTerminateWorker(WebCore::ServiceWorkerIdentifier identifier) -> () Delayed
+ SyncTerminateWorker(WebCore::ServiceWorkerIdentifier identifier) -> () Synchronous
FindClientByIdentifierCompleted(uint64_t clientIdRequestIdentifier, Optional<WebCore::ServiceWorkerClientData> data, bool hasSecurityError)
MatchAllCompleted(uint64_t matchAllRequestIdentifier, Vector<WebCore::ServiceWorkerClientData> clientsData)
ClaimCompleted(uint64_t claimRequestIdentifier)
Modified: trunk/Source/WebKit/WebProcess/WebPage/WebPage.messages.in (243344 => 243345)
--- trunk/Source/WebKit/WebProcess/WebPage/WebPage.messages.in 2019-03-21 23:34:31 UTC (rev 243344)
+++ trunk/Source/WebKit/WebProcess/WebPage/WebPage.messages.in 2019-03-21 23:35:39 UTC (rev 243345)
@@ -78,10 +78,10 @@
ReplaceSelectedText(String oldText, String newText)
RequestAutocorrectionData(String textForAutocorrection, WebKit::CallbackID callbackID)
ApplyAutocorrection(String correction, String originalText, WebKit::CallbackID callbackID)
- SyncApplyAutocorrection(String correction, String originalText) -> (bool autocorrectionApplied) Delayed
+ SyncApplyAutocorrection(String correction, String originalText) -> (bool autocorrectionApplied) Synchronous
RequestAutocorrectionContext()
RequestEvasionRectsAboveSelection() -> (Vector<WebCore::FloatRect> rects) Async
- GetPositionInformation(struct WebKit::InteractionInformationRequest request) -> (struct WebKit::InteractionInformationAtPosition information) Delayed
+ GetPositionInformation(struct WebKit::InteractionInformationRequest request) -> (struct WebKit::InteractionInformationAtPosition information) Synchronous
RequestPositionInformation(struct WebKit::InteractionInformationRequest request)
StartInteractionWithElementAtPosition(WebCore::IntPoint point)
StopInteraction()
@@ -123,7 +123,7 @@
#endif
#if ENABLE(IOS_TOUCH_EVENTS)
- TouchEventSync(WebKit::WebTouchEvent event) -> (bool handled) Delayed
+ TouchEventSync(WebKit::WebTouchEvent event) -> (bool handled) Synchronous
#endif
#if !ENABLE(IOS_TOUCH_EVENTS) && ENABLE(TOUCH_EVENTS)
TouchEvent(WebKit::WebTouchEvent event)
@@ -377,7 +377,7 @@
DrawRectToImage(uint64_t frameID, struct WebKit::PrintInfo printInfo, WebCore::IntRect rect, WebCore::IntSize imageSize, WebKit::CallbackID callbackID)
DrawPagesToPDF(uint64_t frameID, struct WebKit::PrintInfo printInfo, uint32_t first, uint32_t count, WebKit::CallbackID callbackID)
#if PLATFORM(IOS_FAMILY)
- ComputePagesForPrintingAndDrawToPDF(uint64_t frameID, struct WebKit::PrintInfo printInfo, WebKit::CallbackID callbackID) -> (uint32_t pageCount) Delayed
+ ComputePagesForPrintingAndDrawToPDF(uint64_t frameID, struct WebKit::PrintInfo printInfo, WebKit::CallbackID callbackID) -> (uint32_t pageCount) Synchronous
#endif
#endif
#if PLATFORM(GTK)
@@ -407,7 +407,7 @@
#endif
#if PLATFORM (GTK) && HAVE(GTK_GESTURES)
- GetCenterForZoomGesture(WebCore::IntPoint centerInViewCoordinates) -> (WebCore::IntPoint center) Delayed
+ GetCenterForZoomGesture(WebCore::IntPoint centerInViewCoordinates) -> (WebCore::IntPoint center) Synchronous
#endif
#if PLATFORM(COCOA)
@@ -417,16 +417,16 @@
WindowAndViewFramesChanged(WebCore::FloatRect windowFrameInScreenCoordinates, WebCore::FloatRect windowFrameInUnflippedScreenCoordinates, WebCore::FloatRect viewFrameInWindowCoordinates, WebCore::FloatPoint accessibilityViewCoordinates)
SetMainFrameIsScrollable(bool isScrollable)
RegisterUIProcessAccessibilityTokens(IPC::DataReference elemenToken, IPC::DataReference windowToken)
- GetStringSelectionForPasteboard() -> (String stringValue) Delayed
- GetDataSelectionForPasteboard(String pasteboardType) -> (WebKit::SharedMemory::Handle handle, uint64_t size) Delayed
- ReadSelectionFromPasteboard(String pasteboardName) -> (bool result) Delayed
+ GetStringSelectionForPasteboard() -> (String stringValue) Synchronous
+ GetDataSelectionForPasteboard(String pasteboardType) -> (WebKit::SharedMemory::Handle handle, uint64_t size) Synchronous
+ ReadSelectionFromPasteboard(String pasteboardName) -> (bool result) Synchronous
#if ENABLE(SERVICE_CONTROLS)
ReplaceSelectionWithPasteboardData(Vector<String> types, IPC::DataReference data)
#endif
- ShouldDelayWindowOrderingEvent(WebKit::WebMouseEvent event) -> (bool result) Delayed
- AcceptsFirstMouse(int eventNumber, WebKit::WebMouseEvent event) -> (bool result) Delayed
+ ShouldDelayWindowOrderingEvent(WebKit::WebMouseEvent event) -> (bool result) Synchronous
+ AcceptsFirstMouse(int eventNumber, WebKit::WebMouseEvent event) -> (bool result) Synchronous
SetTextAsync(String text)
InsertTextAsync(String text, struct WebKit::EditingRange replacementRange, bool registerUndoGroup, uint32_t editingRangeIsRelativeTo, bool suppressSelectionUpdate)
Modified: trunk/Source/WebKit/WebProcess/WebProcess.messages.in (243344 => 243345)
--- trunk/Source/WebKit/WebProcess/WebProcess.messages.in 2019-03-21 23:34:31 UTC (rev 243344)
+++ trunk/Source/WebKit/WebProcess/WebProcess.messages.in 2019-03-21 23:35:39 UTC (rev 243345)
@@ -77,9 +77,9 @@
ReleasePageCache()
- FetchWebsiteData(PAL::SessionID sessionID, OptionSet<WebKit::WebsiteDataType> websiteDataTypes) -> (struct WebKit::WebsiteData websiteData) Delayed
- DeleteWebsiteData(PAL::SessionID sessionID, OptionSet<WebKit::WebsiteDataType> websiteDataTypes, WallTime modifiedSince) -> () Delayed
- DeleteWebsiteDataForOrigins(PAL::SessionID sessionID, OptionSet<WebKit::WebsiteDataType> websiteDataTypes, Vector<WebCore::SecurityOriginData> origins) -> () Delayed
+ FetchWebsiteData(PAL::SessionID sessionID, OptionSet<WebKit::WebsiteDataType> websiteDataTypes) -> (struct WebKit::WebsiteData websiteData) Synchronous
+ DeleteWebsiteData(PAL::SessionID sessionID, OptionSet<WebKit::WebsiteDataType> websiteDataTypes, WallTime modifiedSince) -> () Synchronous
+ DeleteWebsiteDataForOrigins(PAL::SessionID sessionID, OptionSet<WebKit::WebsiteDataType> websiteDataTypes, Vector<WebCore::SecurityOriginData> origins) -> () Synchronous
SetHiddenPageDOMTimerThrottlingIncreaseLimit(int milliseconds)
#if PLATFORM(COCOA)
@@ -95,7 +95,7 @@
EnsureAutomationSessionProxy(String sessionIdentifier)
DestroyAutomationSessionProxy()
- ProcessWillSuspendImminently() -> (bool handled) Delayed
+ ProcessWillSuspendImminently() -> (bool handled) Synchronous
PrepareToSuspend()
CancelPrepareToSuspend()
ProcessDidResume()
--- trunk/Source/WebKit/Platform/IPC/HandleMessage.h 2019-03-21 23:34:31 UTC (rev 243344)
+++ trunk/Source/WebKit/Platform/IPC/HandleMessage.h 2019-03-21 23:35:39 UTC (rev 243345)
@@ -47,22 +47,8 @@
callMemberFunctionImpl(object, function, std::forward<ArgsTuple>(args), ArgsIndicies());
}
-// Dispatch functions with reply arguments.
+// Dispatch functions with synchronous reply arguments.
-template <typename C, typename MF, typename ArgsTuple, size_t... ArgsIndex, typename ReplyArgsTuple, size_t... ReplyArgsIndex>
-void callMemberFunctionImpl(C* object, MF function, ArgsTuple&& args, ReplyArgsTuple& replyArgs, std::index_sequence<ArgsIndex...>, std::index_sequence<ReplyArgsIndex...>)
-{
- (object->*function)(std::get<ArgsIndex>(std::forward<ArgsTuple>(args))..., std::get<ReplyArgsIndex>(replyArgs)...);
-}
-
-template <typename C, typename MF, typename ArgsTuple, typename ArgsIndicies = std::make_index_sequence<std::tuple_size<ArgsTuple>::value>, typename ReplyArgsTuple, typename ReplyArgsIndicies = std::make_index_sequence<std::tuple_size<ReplyArgsTuple>::value>>
-void callMemberFunction(ArgsTuple&& args, ReplyArgsTuple& replyArgs, C* object, MF function)
-{
- callMemberFunctionImpl(object, function, std::forward<ArgsTuple>(args), replyArgs, ArgsIndicies(), ReplyArgsIndicies());
-}
-
-// Dispatch functions with delayed reply arguments.
-
template <typename C, typename MF, typename CH, typename ArgsTuple, size_t... ArgsIndex>
void callMemberFunctionImpl(C* object, MF function, CompletionHandler<CH>&& completionHandler, ArgsTuple&& args, std::index_sequence<ArgsIndex...>)
{
@@ -75,7 +61,7 @@
callMemberFunctionImpl(object, function, WTFMove(completionHandler), std::forward<ArgsTuple>(args), ArgsIndicies());
}
// Dispatch functions with connection parameter with delayed reply arguments.
template <typename C, typename MF, typename CH, typename ArgsTuple, size_t... ArgsIndex>
void callMemberFunctionImpl(Connection& connection, C* object, MF function, CompletionHandler<CH>&& completionHandler, ArgsTuple&& args, std::index_sequence<ArgsIndex...>)
@@ -103,20 +89,6 @@
callMemberFunctionImpl(object, function, connection, std::forward<ArgsTuple>(args), ArgsIndicies());
}
-// Dispatch functions with connection parameter with reply arguments.
-
-template <typename C, typename MF, typename ArgsTuple, size_t... ArgsIndex, typename ReplyArgsTuple, size_t... ReplyArgsIndex>
-void callMemberFunctionImpl(C* object, MF function, Connection& connection, ArgsTuple&& args, ReplyArgsTuple& replyArgs, std::index_sequence<ArgsIndex...>, std::index_sequence<ReplyArgsIndex...>)
-{
- (object->*function)(connection, std::get<ArgsIndex>(std::forward<ArgsTuple>(args))..., std::get<ReplyArgsIndex>(replyArgs)...);
-}
-
-template <typename C, typename MF, typename ArgsTuple, typename ArgsIndicies = std::make_index_sequence<std::tuple_size<ArgsTuple>::value>, typename ReplyArgsTuple, typename ReplyArgsIndicies = std::make_index_sequence<std::tuple_size<ReplyArgsTuple>::value>>
-void callMemberFunction(Connection& connection, ArgsTuple&& args, ReplyArgsTuple& replyArgs, C* object, MF function)
-{
- callMemberFunctionImpl(object, function, connection, std::forward<ArgsTuple>(args), replyArgs, ArgsIndicies(), ReplyArgsIndicies());
-}
-
// Main dispatch functions
template<typename T>
@@ -148,34 +120,6 @@
}
template<typename T, typename C, typename MF>
-void handleMessageLegacySync(Decoder& decoder, Encoder& replyEncoder, C* object, MF function)
-{
- typename CodingType<typename T::Arguments>::Type arguments;
- if (!decoder.decode(arguments)) {
- ASSERT(decoder.isInvalid());
- return;
- }
-
- typename CodingType<typename T::Reply>::Type replyArguments;
- callMemberFunction(WTFMove(arguments), replyArguments, object, function);
- replyEncoder << replyArguments;
-}
-
-template<typename T, typename C, typename MF>
-void handleMessageLegacySync(Connection& connection, Decoder& decoder, Encoder& replyEncoder, C* object, MF function)
-{
- typename CodingType<typename T::Arguments>::Type arguments;
- if (!decoder.decode(arguments)) {
- ASSERT(decoder.isInvalid());
- return;
- }
-
- typename CodingType<typename T::Reply>::Type replyArguments;
- callMemberFunction(connection, WTFMove(arguments), replyArguments, object, function);
- replyEncoder << replyArguments;
-}
-
-template<typename T, typename C, typename MF>
void handleMessage(Connection& connection, Decoder& decoder, C* object, MF function)
{
typename CodingType<typename T::Arguments>::Type arguments;
@@ -187,7 +131,7 @@
}
template<typename T, typename C, typename MF>
-void handleMessageDelayed(Connection& connection, Decoder& decoder, std::unique_ptr<Encoder>& replyEncoder, C* object, MF function)
+void handleMessageSynchronous(Connection& connection, Decoder& decoder, std::unique_ptr<Encoder>& replyEncoder, C* object, MF function)
{
typename CodingType<typename T::Arguments>::Type arguments;
if (!decoder.decode(arguments)) {
@@ -202,7 +146,7 @@
}
template<typename T, typename C, typename MF>
-void handleMessageDelayedWantsConnection(Connection& connection, Decoder& decoder, std::unique_ptr<Encoder>& replyEncoder, C* object, MF function)
+void handleMessageSynchronousWantsConnection(Connection& connection, Decoder& decoder, std::unique_ptr<Encoder>& replyEncoder, C* object, MF function)
{
typename CodingType<typename T::Arguments>::Type arguments;
if (!decoder.decode(arguments)) {
@@ -75,7 +61,7 @@
callMemberFunctionImpl(object, function, WTFMove(completionHandler), std::forward<ArgsTuple>(args), ArgsIndicies());
}
-// Dispatch functions with connection parameter with delayed reply arguments.
+// Dispatch functions with connection parameter with synchronous reply arguments.
template <typename C, typename MF, typename CH, typename ArgsTuple, size_t... ArgsIndex>
void callMemberFunctionImpl(Connection& connection, C* object, MF function, CompletionHandler<CH>&& completionHandler, ArgsTuple&& args, std::index_sequence<ArgsIndex...>)
Modified: trunk/Source/WebKit/PluginProcess/PluginControllerProxy.messages.in (243344 => 243345)